# ================================================================
# Examples of the documentation of Model DPSDT:
# DPSDT-2.3: Modeling Associative Recognition
#
# Data from Kelley and Wixted, Exp.3
# Date of creation: November, 2013
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-DPSDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# DATA OF KELLEY & WIXTED (2001), Experiment 3
data <- c(662, 302, 208,  33,  30,   5,	# Exp.3: Lure   items
	    119,  66,  55,  24,  15,  31,	# Exp.3: Weak   Items, rearranged
	     41,  37,  49,  18,  27, 138,	# Exp.3: Weak   Items, intact
	    151,  41,  44,  21,  22,  31,	# Exp.3: Strong Items, rearranged
	      9,  10,  17,  19,  34, 221)	# Exp.3: Strong Items, intact

cat("\n-------------------------------------------------------------------------\n")
cat(" DPSDT 1A: Associative recognition (Data from Kelley and Wixted, Exp.3:\n")
cat("           restriction = \"standard-lure-pairs-eq\"\n")
cat("           - Distribution 1 = N(0,1) [Lure]\n")
cat("           - recollection[2] = 0, recollection[4] = 0\n") 
cat("           - stddev[2] = stddev[3] = stddev[4] = stddev[5]\n\n")
cat("           COMMENT:\n")
cat("           Problem of identification due to the fact that the recollection\n")
cat("           parameter of the last model is on the limitr (zero)")
cat("\n-------------------------------------------------------------------------\n")
cfg <- list(n.sdt = 5, restriction = "standard-lure-pairs-eq", rec.pos = c(1, 1, 6, 1, 6))
Opti1A.Obj <- SDT.Estimate(data = data, Model.Id = "DPSDT", n = cfg, test = T)
Stat1A.Obj <- SDT.Statistics(Opti1A.Obj)
print(Stat1A.Obj)

cat("\n-------------------------------------------------------------------------\n")
cat(" DPSDT 1B: Associative recognition (Data from Kelley and Wixted, Exp.3:\n")
cat("           restriction = \"standard-lure-pairs-eq\"\n")
cat("           - Distribution 1 = N(0,1) [Lure]\n")
cat("           - recollection[2] = 0, recollection[4] = recollection[5] = 0\n") 
cat("           - stddev[2] = stddev[3] = stddev[4] = stddev[5] = 1.0\n\n")
cat("           COMMENT:\n")
cat("           Recollection parameter of last model is set to zero in order\n")
cat("           to overcome problems of identification")
cat("\n-------------------------------------------------------------------------\n")
cfg <- list(n.sdt = 5, restriction = "standard-lure-pairs-eq", rec.pos = c(1, 1, 6, 1, 6))
fixed <- matrix(c(0, 33), nr = 2, byrow = T)
Opti1B.Obj <- SDT.Estimate(data = data, Model.Id = "DPSDT", n = cfg, fixed = fixed, test = T)
Stat1B.Obj <- SDT.Statistics(Opti1B.Obj)
print(Stat1B.Obj)


cat("\n-------------------------------------------------------------------------\n")
cat(" DPSDT 2: Associative recognition (Data from Kelley and Wixted, Exp.3:\n")
cat("          restriction = \"standard-lure-pairs-eq\"\n")
cat("          - Distribution 1 = N(0,1) [Lure]\n")
cat("          - recollection[2] = 0, recollection[4] = 0\n") 
cat("          - stddev[2] = stddev[3] = stddev[4] = stddev[5] = 1.0")
cat("\n-------------------------------------------------------------------------\n")
cfg <- list(n.sdt = 5, restriction = "standard-lure-pairs", rec.pos = c(1, 1, 6, 1, 6))
Opti2.Obj <- SDT.Estimate(data = data, Model.Id = "DPSDT", n = cfg, test = T)
Stat2.Obj <- SDT.Statistics(Opti2.Obj)
print(Stat2.Obj)


