# ================================================================
# Examples of the documentation of SDT Models:
# Gauss-1.2: Modeling of Yes/No data (Gaussian version)
#            Symmetric restriction
#
# Date of last update: August, 2013
# Autor: Siegfried Macho
# ================================================================

library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))


datavec <- c(1780, 763, 	# NEW
	        883, 1025)	# OLD

cfg <- list(n.sdt = 2, restriction = "equalvar-symmetric")

# SHOW PARAMETR INFORMATION
PI <- SDT.Parameter.Info(data = datavec, n = cfg, Model.Id = "Gaussian")
cat("\n------------------------------------------\n")
cat("  Parameter-Information (Gaussian Model):")
cat("\n------------------------------------------\n")
print(PI)

# ESTIMATE AND EVALUATE THE RESULTS
Opti.Obj <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "Gaussian", test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)
print(Stat.Obj)


# PLOT CONFIGURATION
SDT.Plot(Opti.Obj, cols = 3:4, labels = c("Memory Strength", "Density"), SDT.legend = list(text = c("New", "Old")))
