# ================================================================
# Examples of the documentation of Gaussian:
# Gauss-2: Illustration of the function SDT.Estimate (2 signals)
# Data:    Ratcliff et al. (1994)
#
# Date of last update: August, 2013
# Author: Siegfried Macho
# ================================================================

library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))


# DATA OF RATCLIFF ET AL. (1994, Exp.1, 200 ms pure strong list)
data <- c(477, 776, 527, 321, 258, 184,			# New
	    192, 401, 290, 267, 316, 442)			# Old

Opti.Obj <- SDT.Estimate(data = data, Model.Id = "Gaussian", test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results
print(Stat.Obj)

# PLOT CONFIGURATION

# Plot density curves
SDT.Plot(Opti.Obj, cols = 3:4, labels = c("Memory Strength", "Density"), SDT.legend = list(text = c("New", "Old")))

# Plot ROC curve with data
SDT.Plot(Opti.Obj, cols = 3, labels = c("False Alarms", "Hits"), option = "ROC+")

# Plot zROC curve with data
SDT.Plot(Opti.Obj, cols = 3, labels = c("z(FA)", "z(H)"), option = "zROC+")
