# =============================================================================================
# Examples of the documentation of Gaussian:
# Gaus-5.2:  Illustration of fitting unequal numbers of data points for different types of signals
#            Computation of LR confidence intervals
#
# Date of last update: August, 2013
# Author: Siegfried Macho
# =============================================================================================

library(numDeriv)

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

n.data <- c(7, 4, 3, 6, 2)		# NUMBER OF DATA POINTS PER SIGNAL

# ARTIFICIAL DATA
data <- c( 24,  22,  57,  10,  12,  17,  7,	# Signal 1: 7 data points
	    210,  34,   5,   1,				# Signal 2: 4 data points
	     60, 103,   8,				# Signal 3: 3 data points
		0,   5, 198, 225, 148,  13,		# Signal 4: 6 data points
	    121,  69)					# Signal 5: 2 data points

# FIXED: DISTRIBUTION OF FIRST AND FIFTH SIGNAL = N(0,1)
fixed <- matrix(c(0, 1,	 0,  1,					
			1, 2, 25, 26), nr = 2, byrow = T)

# EQUALITY CONSTRAINTS ON THRESHOLDS FOR DIFFERENT SIGNALS:
# 1. CONSTRAINTS ON THRESHOLDS ASSOCIATED WITH SIGNAL 2
ident.2 <- matrix(c(4:6,  
			  3:5+8), nr = 2, byrow = T)

# 2. CONSTRAINTS ON THRESHOLDS ASSOCIATED WITH SIGNAL 3
ident.3 <- matrix(c(4:5,  
			  3:4+13), nr = 2, byrow = T)

# 3. CONSTRAINTS ON THRESHOLDS ASSOCIATED WITH SIGNAL 4
ident.4 <- matrix(c(3:7,  
			  3:7+17), nr = 2, byrow = T)

# 4. CONSTRAINTS ON THRESHOLDS ASSOCIATED WITH SIGNAL 5
ident.5 <- matrix(c(5,  
			  3+24), nr = 2, byrow = T)

ident <- cbind(ident.2, ident.3, ident.4, ident.5)

# ESTIMATE THE MODEL
Opti.Obj <- SDT.Estimate(data = data, Model.Id = "Gaussian", n = n.data, fixed = fixed, ident = ident, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj, control = list(LR = T))

cat("\n============================================================\n")
cat(" Result of the Gaussian model with unequal data per signal:")
cat("\n Data points per signal: n =(", n.data, ")")
cat("\n============================================================\n")
print(Stat.Obj)