# ================================================================
# Examples of the documentation of Model HT.n:
# HT.n-1.1: Exclusion vs. inclusion
# Data from Yonelinas (1994), Exp.1
#
# Date of creation: October, 2009
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-HT-n.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# DATA OF YONELINAS (1994), Experiment 1: SHORT LISTS
data.short <-   c(598, 472, 241,  95,  28,   6,   # Distractors
                  669, 300, 157, 159, 101,  54,   # Exclusion items
                   56, 120, 136, 179, 241, 708)   # Inclusion items

# DATA OF YONELINAS (1994), Experiment 1: LONG LISTS
data.long  <-   c(368, 520, 335, 145,  65,   7,   # Distractors
                  460, 318, 225, 222, 166,  49,  # Exclusion items
                   50, 185, 200, 238, 268, 499)   # Inclusion items

n <- 3

#===============================================================================
#
# 1. HT.3 MODEL: SHORT LISTS
#
#===============================================================================
# Specification of constraints
fixed.dist <- matrix(c(rep(0, 6),  1,                             # Distractors
                             1:6,  7), nr = 2, byrow = T)
                         
fixed.exc.inc <- matrix(c(rep(0, 6),        1,  1,                # Fixed constraints exclusion / inclusion
                              14:16, 20:22, 9, 18), nr = 2, byrow = T)
                        
fixed <- cbind(fixed.dist, fixed.exc.inc)
ident <- matrix(c(11:13,   8, 10,
                  25:23,  17, 19), nr = 2, byrow = T)

# Compute start parameter vector
par <- SDT.HT.n.start.par(n, data.short)

# Add redundant parameters so that their positions can be seen in the output
fixed.show <- HT.n.Redundant.to.Fixed(par, n, fixed, ident)

# Compute Parameter information
Par.Info <- SDT.Parameter.Info(par = par, n = n, Model.Id = "HT.n", fixed = fixed.show, ident = ident)
cat("\n-------------------------------------------------------------\n")
cat("HT.3: Yonelinas (1994), Exp.1, Parameter-Information:")
cat("\n-------------------------------------------------------------\n")
print(Par.Info)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.3: Yonelinas (1994), Exp.1, short lists")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = data.short, n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.3: Yonelinas (1994), Exp.1, long lists")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = data.long, n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

#===============================================================================
#
# 2. HT.2 MODEL: WEAK AND STRONG ITEMS SEPARATELY
#
#===============================================================================

# Specify additional fixed constraints: p3[1] = 0 (P 4) , p4[2] = 0 (P 14)
fixed.add <- matrix(c(0,   0, 
                      13, 23), nr = 2, byrow = T)
fixed <- cbind(fixed, fixed.add)

# Remove the equality constraint p3[1] = p4[2]
ident <- matrix(c(11:12,   8, 10,
                  25:24,  17, 19), nr = 2, byrow = T)

# Add redundant parameters so that their positions can be seen in the output
fixed.show <- HT.n.Redundant.to.Fixed(par, n, fixed, ident)

# Compute Parameter information
Par.Info.HT.2 <- SDT.Parameter.Info(par = par, n = n, Model.Id = "HT.n", fixed = fixed.show, ident = ident)
cat("\n-------------------------------------------------------------\n")
cat("HT.2: Kelley & Wixted, Exp.1, Parameter-Information:")
cat("\n-------------------------------------------------------------\n")
print(Par.Info.HT.2)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.2: Yonelinas (1994), Exp.1, short lists")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = data.short, n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.2: Yonelinas (1994), Exp.1, long lists")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = data.long, n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)
