# ================================================================
# Examples of the documentation of Model HT.n:
# HT.n-2.2: Associative recognition
# Data from Kelley & Wixted (2001), Exp.3
# Date of creation: October, 2009
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-HT-n.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# DATA OF KELLEY & WIXTED (2001), Experiment 3
data <- c(662, 302, 208,  33,  30,   5,	# Exp.3: Lure   items
	    119,  66,  55,  24,  15,  31,	# Exp.3: Weak   Items, rearranged
	     41,  37,  49,  18,  27, 138,	# Exp.3: Weak   Items, intact
	    151,  41,  44,  21,  22,  31,	# Exp.3: Strong Items, rearranged
	      9,  10,  17,  19,  34, 221)	# Exp.3: Strong Items, intact

# NUMBER OF CONDITIONS (TYPES OF SIGNALS)
n <- 5

#===============================================================================
#
# 1. HT.3 MODEL: WEAK AND STRONG ITEMS
#
#===============================================================================

# Specification of constraints for HT.3
fixed.null <- matrix(c(rep(0, 6),  1,
                             1:6,  7), nr = 2, byrow = T)
                         
fixed.weak <- matrix(c(rep(0, 6), 
                           14:16, 20:22), nr = 2, byrow = T)
                        
ident.weak <- matrix(c(11:13, 8:9, 
                       25:23, 17:18), nr = 2, byrow = T)

fixed.strong <- matrix(c(rep(0, 6),
                         32:34, 38:40), nr = 2, byrow = T)
                         
ident.strong <- matrix(c(11:13, 11:13, 26:27,
                         29:31, 43:41, 35:36), nr = 2, byrow = T)
                         
fixed <- cbind(fixed.null, fixed.weak, fixed.strong)
ident <- cbind(ident.weak, ident.strong)

# Compute start parameter vector
par <- SDT.HT.n.start.par(n, data)

# Add redundant parameters so that ist position can be seen in output
fixed.show <- HT.n.Redundant.to.Fixed(par, n, fixed, ident)

# Compute Parameter information
Par.Info <- SDT.Parameter.Info(par = par, n = n, Model.Id = "HT.n", fixed = fixed.show, ident = ident)
cat("\n-------------------------------------------------------------\n")
cat("HT.3: Kelley & Wixted, Exp.3, Parameter-Information:")
cat("\n-------------------------------------------------------------\n")
print(Par.Info)


cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.3: Kelley & Wixted, Exp.3, Weak and strong items:")
cat("\n------------------------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = data, n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

#===============================================================================
#
# 2. HT.2 MODEL: WEAK AND STRONG ITEMS
#
#===============================================================================

# Specification of constraints for HT.2
fixed.weak <- matrix(c(rep(0, 8), 
                           13:16, 20:23), nr = 2, byrow = T)
                        
ident.weak <- matrix(c(11:12, 8:9, 
                       25:24, 17:18), nr = 2, byrow = T)

fixed.strong <- matrix(c(rep(0, 8),
                         31:34, 38:41), nr = 2, byrow = T)
                         
ident.strong <- matrix(c(11:12, 11:12, 26:27,
                         29:30, 43:42, 35:36), nr = 2, byrow = T)
                         
fixed <- cbind(fixed.null, fixed.weak, fixed.strong)
ident <- cbind(ident.weak, ident.strong)
# Compute start parameter vector
par <- SDT.HT.n.start.par(n, data)

# Add redundant parameters so that ist position can be seen in output
fixed.show <- HT.n.Redundant.to.Fixed(par, n, fixed, ident)

# Compute Parameter information
Par.Info <- SDT.Parameter.Info(par = par, n = n, Model.Id = "HT.n", fixed = fixed.show, ident = ident)
cat("\n-------------------------------------------------------------\n")
cat("HT.2: Kelley & Wixted, Exp.3, Parameter-Information:")
cat("\n-------------------------------------------------------------\n")
print(Par.Info)

cat("\n------------------------------------------------------------------------------------\n")
cat(" HT.2: Kelley & Wixted, Exp.3, Weak and strong items:")
cat("\n------------------------------------------------------------------------------------\n")
Opti2.Obj <- SDT.Estimate(data = data, n = n, Model.Id = "HT.n", fixed = fixed, ident = ident, test = T)
Stat2.Obj <- SDT.Statistics(Opti2.Obj)
print(Stat2.Obj)
