# ================================================================
# Ex.0: HTSDT-Bias-Rank model
#       Demosntration of standard restrictions
# 
# Date of creation: July, 2013
# Autor: Siegfried Macho
# ================================================================

# Names of directories: PLEASE ADJUST TO YOUR PERSONAL SETTING
Dir  <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"
DirM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# Names of the source files required for estimating the data
NameS <- "SDT-Main.R"
NameA <- "SDT-Auxiliary.R"
NameM <- "HTSDT-Bias-Rank.R"
# Load source files
source(paste(Dir,  NameA, sep = ""))
source(paste(Dir,  NameS, sep = ""))
source(paste(DirM, NameM, sep = ""))

#===============================================================================
# Configuration 1: HTSDT.Bias.Rank model: Ranking only, one model
#                  Three types of restrictions: standard, SDT, extended
#===============================================================================

cat("\n--------------------------------------------------------------------\n")
cat(" Configuration 1-1: HTSDT.Bias.Rank model: Standard restriction\n")
cat("    cfg = list(j.rg = 4, rating = F)")
cat("\n--------------------------------------------------------------------\n")
cfg <- list(j.rg = 4, rating = F)
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "HTSDT.Bias.Rank")
print(Erg)

cat("\n-----------------------------------------------------------------\n")
cat(" Configuration 1-2: HTSDT.Bias.Rank model: SDT restriction\n")
cat("    cfg = list(j.rg = 4, rating = F, restriction = \"SDT\")")
cat("\n-----------------------------------------------------------------\n")
cfg <- list(j.rg = 4, rating = F, restriction = "SDT")
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "HTSDT.Bias.Rank")
print(Erg)

cat("\n-----------------------------------------------------------------\n")
cat(" Configuration 1-3: HTSDT.Bias.Rank model: Extended restriction\n")
cat("    cfg = list(j.rg = 4, rating = F, restriction = \"extended\")")
cat("\n-----------------------------------------------------------------\n")
cfg <- list(j.rg = 4, rating = F, restriction = "extended")
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "HTSDT.Bias.Rank")
print(Erg)

#===============================================================================
# Configuration 2: Ranking only, multiple models
#                  Three types of restrictions: standard, SDT, extended
#===============================================================================

cat("\n-----------------------------------------------------------------\n")
cat(" Configuration 2-1: HTSDT.Bias.Rank model: Standard restriction\n")
cat("    cfg = list(j.rg = c(4, 3, 2), rating = F)")
cat("\n-----------------------------------------------------------------\n")
cfg <- list(j.rg = c(4, 3, 2), rating = F)
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "HTSDT.Bias.Rank")
print(Erg)

cat("\n-----------------------------------------------------------------\n")
cat(" Configuration 2-2: HTSDT.Bias.Rank model: SDT restriction\n")
cat("    cfg = list(j.rg = c(4, 3, 2), rating = F, restriction = \"SDT\")")
cat("\n-----------------------------------------------------------------\n")
cfg <- list(j.rg = c(4, 3, 2), rating = F, restriction = "SDT")
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "HTSDT.Bias.Rank")
print(Erg)

cat("\n----------------------------------------------------------------------\n")
cat(" Configuration 2-3: HTSDT.Bias.Rank model: Extended restriction\n")
cat("    cfg = list(j.rg = c(4, 3, 2), rating = F, restriction = \"extended\")")
cat("\n----------------------------------------------------------------------\n")
cfg <- list(j.rg = c(4, 3, 2), rating = F, restriction = "extended")
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "HTSDT.Bias.Rank")
print(Erg)


#===============================================================================
# Configuration 3: Ranking and rating, multiple models
#                  Three types of restrictions: standard, SDT, extended
#===============================================================================
cat("\n-----------------------------------------------------------------\n")
cat(" Configuration 3-1: HTSDT.Bias.Rank model:\n")
cat(" Standard restriction, 6 response categories\n")
cat("    cfg = list(j.rg = c(4, 3), rating = T)")
cat("\n-----------------------------------------------------------------\n")
cfg <- list(n.sdt = 2, j.rg = c(4, 3), k.rg = c(4, 3), rating = T)
datavec <- rep(0, sum(cfg$j.rg * cfg$k.rg) + cfg$n.sdt*6)           # Data vector required with rating model 
Erg <- SDT.Parameter.Info(data = datavec, n = cfg, Model.Id = "HTSDT.Bias.Rank")
print(Erg)

cat("\n-----------------------------------------------------------------\n")
cat(" Configuration 3-2: HTSDT.Bias.Rank model:\n")
cat(" SDT restriction, 6 response categories\n")
cat("    cfg = list(j.rg = c(4, 3), rating = T, restriction = \"SDT\")")
cat("\n-----------------------------------------------------------------\n")
cfg <- list(j.rg = c(4, 3), rating = T, restriction = "SDT")
Erg <- SDT.Parameter.Info(data = datavec, n = cfg, Model.Id = "HTSDT.Bias.Rank")
print(Erg)

cat("\n----------------------------------------------------------------------\n")
cat(" Configuration 3-3: HTSDT.Bias.Rank model:\n")
cat(" Extended restriction, 6 response categories\n")
cat("    cfg = list(j.rg = c(4, 3), rating = T, restriction = \"extended\")")
cat("\n----------------------------------------------------------------------\n")
cfg <- list(j.rg = c(4, 3), rating = T, restriction = "extended")
Erg <- SDT.Parameter.Info(data = datavec, n = cfg, Model.Id = "HTSDT.Bias.Rank")
print(Erg)
