# ================================================================
# Ex.2: HTSDT-Rank model: ARC and Rating
# Data. Kellen et al (2012)
#
# Date of creation:        June, 2013
# Date of last update: December, 2020
# Autor: Siegfried Macho
# ================================================================
rm(list = ls())

# Names of directories: PLEASE ADJUST TO YOUR PERSONAL SETTING
DirM  <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/Models/"
Dir   <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/"

# Names of the source files required for estimating the data
NameS <- "SDT-Main.R"
NameA <- "SDT-Auxiliary.R"
NameM <- "HTSDT-Rank.R"

# Load source files
source(paste(Dir,  NameA, sep = ""))
source(paste(Dir,  NameS, sep = ""))
source(paste(DirM, NameM, sep = ""))


T1 <- T
T2 <- T

#===============================================================================
# 1. Estimation of ranking and rating with standard restriction
#===============================================================================
if(T1) {
   cfg <- list(n.sdt = c(2, 6), k.rg = 4, rating = T, restriction = "standard")
   # Data vector of Kellen, Klauer & Singmann (2012), pooled data
   datavec <- c(1801, 488, 407, 304,                 # 1. Ranking data
                 667, 780, 651, 485, 277,  140,      # 2. Rating data (new)
                 198, 303, 402, 421, 426, 1250)      # 3. Rating data (old)
  Opti.Obj <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "HTSDT.Rank", test = T)
  Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results
  cat("\n-------------------------------------------------------------------------\n")
  cat("Model 1:  HTSDT-Modell AFC + rating\n")
  cat("          standard restrictions\n")
  cat("          AFC: k.rg = 4\n")
  cat("          SDT: c(2, 6)")
  cat("\n-------------------------------------------------------------------------\n")
  print(Stat.Obj)
}

if(T2) {
   cfg <- list(n.sdt = c(2, 6), k.rg = 4, rating = T, restriction = "equal")
   # Data vector of Kellen, Klauer & Singmann (2012), pooled data
   datavec <- c(1801, 488, 407, 304,                 # 1. Ranking data
                 667, 780, 651, 485, 277,  140,      # 2. Rating data (new)
                 198, 303, 402, 421, 426, 1250)      # 3. Rating data (old)
  Opti.Obj <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "HTSDT.Rank", test = T)
  Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results
  cat("\n-------------------------------------------------------------------------\n")
  cat("Model 2:  HTSDT-Modell AFC + rating\n")
  cat("          equality restrictions\n")
  cat("          AFC: k.rg = 4\n")
  cat("          SDT: c(2, 6)")
  cat("\n-------------------------------------------------------------------------\n")
  print(Stat.Obj)
}
