# ================================================================
# T6.1: Test examples of the module SDT-Rank
# Estimation of the own data)
#
# Date of creation:    December, 2020
# Date of last update: December, 2020
# Autor: Siegfried Macho
# ================================================================
rm(list = ls())

Dir <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/"
DirM <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/Models/"
DirD <- "C:/Users/macho/Documents/Statistik/Kellen & Klauer (2012)/"

# Old version
#Dir <- "U:/My Documents/_Sicherung/Statistik/_SDT-Models (Version 2)/R-Code/"
#DirM <- "U:/My Documents/_Sicherung/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

NameS <- "SDT-Main.R"
NameA <- "SDT-Auxiliary.R"
NameM <- "HTSDT-Rank.R"
NameM2<- "SDT-SDT.R"
NameD <- "data_rank_rate.txt"

source(paste(Dir,  NameA, sep = ""))
source(paste(Dir,  NameS, sep = ""))
source(paste(DirM, NameM, sep = ""))
source(paste(DirM, NameM2, sep = ""))


data.pooled <- c(10198, 3209, 2252, 1621,              # 4-AFC
                 11382, 3519, 2379,                    # 3-SFC
                 4611,  4340, 3357, 2663, 1618,  691,  # 6-Rating (New)
                 1309,  2049, 2274, 2620, 2493, 6535,  # 6 Rating (Old)
                 5508,  6711, 3987, 1074,              # 4-Rating (New)
                 1837,  3959, 4330, 7154)              # 4-Rating (old)

#------------------------------------------------------------
# POSITIONEN OF DATA FOR DIFFERENT MODELS
#------------------------------------------------------------
Range.AFC4 <- 1:4
Range.AFC3 <- 5:7
Range.AFC  <- 1:7
Range.Ra6  <- 8:19
Range.Ra4  <- 20:27
Range.Ra   <- 8:27
  
#-------------------------------------
# Konfigurationen fr die Modelle:
#-------------------------------------
cfg.AFC.3    <- list(k.rg = 3, rating = F)
cfg.AFC.4    <- list(k.rg = 4, rating = F)
cfg.AFC      <- list(k.rg = c(4, 3), rating = F)
cfg.AFC.e    <- list(k.rg = c(4, 3), rating = F, restriction = "equal")

cfg.all       <- list(n.sdt = c(2, 6, 2, 4), k.rg = c(4, 3), rating = T)
cfg.all.equal <- list(n.sdt = c(2, 6, 2, 4), k.rg = c(4, 3), rating = T, restriction = "equal")

cfg.none.all       <- list(n.sdt = c(2, 6, 2, 4), k.rg = c(4, 3), j.rg = c(2, 2), rating = T)
cfg.none.all.equal <- list(n.sdt = c(2, 6, 2, 4), k.rg = c(4, 3), j.rg = c(2, 2), rating = T, restriction = "equal")

T1 <- F
T2 <- F
T3 <- T

#===============================================================================
# 1. Estimation of ranking data only (sparately and together)
#===============================================================================
if(T1) {
   Opti.A4.Obj  <- SDT.Estimate(data = data.pooled[Range.AFC4], n = cfg.AFC.4, Model.Id = "HTSDT.Rank", test = T)
   Opti.A3.Obj  <- SDT.Estimate(data = data.pooled[Range.AFC3], n = cfg.AFC.3, Model.Id = "HTSDT.Rank", test = T)
   Opti.A.Obj   <- SDT.Estimate(data = data.pooled[Range.AFC],  n = cfg.AFC,   Model.Id = "HTSDT.Rank", test = T)
   Opti.Ae.Obj  <- SDT.Estimate(data = data.pooled[Range.AFC],  n = cfg.AFC.e, Model.Id = "HTSDT.Rank", test = T)
  
   Stat.A4.Obj  <- SDT.Statistics(Opti.A4.Obj, display.warning = F)			# Evaluate the results
   Stat.A3.Obj  <- SDT.Statistics(Opti.A3.Obj, display.warning = F)			# Evaluate the results
   Stat.A.Obj   <- SDT.Statistics(Opti.A.Obj,  display.warning = F)			# Evaluate the results
   Stat.Ae.Obj  <- SDT.Statistics(Opti.Ae.Obj, display.warning = F)			# Evaluate the results
   
   cat("\n-------------------------------------------------------------------------\n")
   cat("TEST 1.1: 4-AFC data, only")
   cat("\n-------------------------------------------------------------------------\n")
   print(Stat.A4.Obj)
   
   cat("\n-------------------------------------------------------------------------\n")
   cat("TEST 1.2: 3-AFC data")
   cat("\n-------------------------------------------------------------------------\n")
   print(Stat.A3.Obj)

   cat("\n-------------------------------------------------------------------------\n")
   cat("TEST 1.3: 4-AFC and 3-AFC data together")
   cat("\n-------------------------------------------------------------------------\n")
   print(Stat.A.Obj)

   cat("\n-------------------------------------------------------------------------\n")
   cat("TEST 1.4: 4-AFC and 3-AFC data together with equality constraints")
   cat("\n-------------------------------------------------------------------------\n")
   print(Stat.Ae.Obj)
}

#===============================================================================
# 2. Estimation of both ranking and rating dat
#===============================================================================

if(T2) {
   Opti.all.Obj      <- SDT.Estimate(data = data.pooled, n = cfg.all, Model.Id = "HTSDT.Rank", test = T)       # Standard restrictions
   Opti.all.equ.Obj  <- SDT.Estimate(data = data.pooled, n = cfg.all.equal, Model.Id = "HTSDT.Rank", test = T) # Equal parameters

   Stat.all.Obj      <- SDT.Statistics(Opti.all.Obj, display.warning = F)			# Evaluate the results
   Stat.all.equ.Obj  <- SDT.Statistics(Opti.all.equ.Obj, display.warning = F)	# Evaluate the results
  
   cat("\n-------------------------------------------------------------------------\n")
   cat("TEST 2.1: All data (AFC and rating), standard restrictions")
   cat("\n-------------------------------------------------------------------------\n")
   print(Stat.all.Obj)
   
   cat("\n-------------------------------------------------------------------------\n")
   cat("TEST 2.2: All data (AFC and rating), equality restrictions")
   cat("\n-------------------------------------------------------------------------\n")
   print(Stat.all.equ.Obj)
}

#===============================================================================
# 3. Estimation of both ranking and rating dat AFC data without repetition
#===============================================================================

if(T3) {
   datvec <- c(data.pooled[1], sum(data.pooled[2:4]), data.pooled[5], sum(data.pooled[6:7]), data.pooled[Range.Ra])
   Opti.none.all.equ.Obj  <- SDT.Estimate(data = datvec, n = cfg.none.all.equal, Model.Id = "HTSDT.Rank", test = T) # Equal parameters
   Stat.none.all.equ.Obj  <- SDT.Statistics(Opti.none.all.equ.Obj, display.warning = F)			# Evaluate the results
  
   cat("\n-------------------------------------------------------------------------\n")
   cat("TEST 3.1: All data (AFC without repetition and rating), equality restrictions")
   cat("\n-------------------------------------------------------------------------\n")
   print(Stat.none.all.equ.Obj)
}
