# ================================================================
# MIX-2.4: Examples of the documentation of Model MIX.2:
# Modeling Process dissoication data from Yonelinas (1994)
#
# Model: DeCarlo (2008)
# Data:  Yonelinas (1994)
#
# Date of creation: May, 2010
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-2.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

n <- 3
# DATA: YONELINAS 1994), Exp.1, SHORT LISTS
data.1_short <- c(598, 472, 241,  95,  28,   6,             # Distractor
                  669, 300, 157, 159, 101,  54,             # Exclusion
                   56, 120, 136, 179, 241, 708)             # Inclusion
                   
# DATA: YONELINAS 1994), Exp.1, LONG LISTS
data.1_long  <- c(368, 520, 335, 145,  65,   7,             # Distractor
                  460, 318, 225, 222, 166,  49,             # Exclusion
                   50, 185, 200, 238, 268, 499)             # Inclusion


# DATA: YONELINAS 1994), Exp.2, SHORT LISTS
data.2_short <- c(509, 495,  98,  30,  16,   4,             # Distractor
                  557, 263, 137,  78,  75,  42,             # Exclusion
                   51, 109,  88, 105, 214, 585)             # Inclusion

# DATA: YONELINAS 1994), Exp.2, SHORT LISTS
data.2_long  <- c(307, 530, 192,  79,  39,   5,             # Distractor
                  335, 308, 162, 178, 126,  43,             # Exclusion
                   46, 179, 130, 189, 252, 356)             # Inclusion

data.3 <- c(969, 576, 403, 282, 215, 115,                   # Distractor
            296, 200, 153, 141, 180, 130,                   # Exclusion (weak)
            194, 190, 150, 135, 177, 254,                   # Inclusion (weak)
            351, 170, 150, 120, 162, 187,                   # Exclusion (strong)
            167, 132, 123, 136, 210, 372)                   # Inclusion (strong)

 
# 1. FIXED CONSTRAINTS		
# 1.1 FIX MEAN OF DISTRACTORS TO 0
fixed.m <- matrix(c(0, 0, 
                    2, 4), nr = 2, byrow = T)

# 1.2 FIX ALL SD TO 1.0
fixed.sd <- matrix(c(1, 1,  1,  1,  1,  1,  
                     3, 5, 13, 15, 23, 25), nr = 2, byrow = T)

# 1.3 FIX PROBABILITY OF DISTRACTOR DISTRIBUTION
fixed.p <- matrix(c(0, 
                    1), nr = 2, byrow = T)

# 1.4 COMBINE FIXED CONSTRAINTS
fixed <- cbind(fixed.m, fixed.sd, fixed.p)


# 2. EQUALITY CONSTRAINTS: IDENTICAL PROBABILITIES AS WELL AS IDENTICAL THRESHOLDS
ident <- matrix(c(6:10,    6:10,
	   	      6:10+10, 6:10+20), nr = 2, byrow = T)

cat("\n---------------------------------------------------------------------\n")
cat(" MIX-2: Parameter information:")
cat("\n Model: DeCarlo (2008), Data from Yonelinas, Exp.1:")
cat("\n---------------------------------------------------------------------\n")
Par.Info <- SDT.Parameter.Info (data = data.1_short, Model.Id = "MIX.2", n = n, fixed = fixed, ident = ident)
print(Par.Info)


cat("\n------------------------------------------------------------------------------------\n")
cat(" MIX-2: Yonelinas (1994): Exp.1, short lists")
cat("\n------------------------------------------------------------------------------------\n")
Opti11.Obj <- SDT.Estimate(data = data.1_short, Model.Id = "MIX.2", n = n, fixed = fixed, ident = ident, test = T)
Stat11.Obj <- SDT.Statistics(Opti11.Obj)
print(Stat11.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" MIX-2: Yonelinas (1994): Exp.1, long lists")
cat("\n------------------------------------------------------------------------------------\n")
Opti12.Obj <- SDT.Estimate(data = data.1_long, Model.Id = "MIX.2", n = n, fixed = fixed, ident = ident, test = T)
Stat12.Obj <- SDT.Statistics(Opti12.Obj)
print(Stat12.Obj)


cat("\n------------------------------------------------------------------------------------\n")
cat(" MIX-2: Yonelinas (1994): Exp.2, short lists")
cat("\n------------------------------------------------------------------------------------\n")
Opti21.Obj <- SDT.Estimate(data = data.2_short, Model.Id = "MIX.2", n = n, fixed = fixed, ident = ident, test = T)
Stat21.Obj <- SDT.Statistics(Opti21.Obj)
print(Stat21.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" MIX-2: Yonelinas (1994): Exp.2, long lists")
cat("\n------------------------------------------------------------------------------------\n")
Opti22.Obj <- SDT.Estimate(data = data.2_long, Model.Id = "MIX.2", n = n, fixed = fixed, ident = ident, test = T)
Stat22.Obj <- SDT.Statistics(Opti22.Obj)
print(Stat22.Obj)

# EXPERIMENT 3: ADDITIONAL CONSTRINTS FOR SIGMALS 4 & 5
# Fixed Constraints
fixed.sd.3.4 <-  matrix(c( 1,  1,  1,  1,  
                          33, 35, 43, 45), nr = 2, byrow = T)
                          
fixed <- cbind(fixed, fixed.sd.3.4)

# Identity Constraints
ident.3.4 <- matrix(c(6:10,    6:10,
	           	    6:10+30, 6:10+40), nr = 2, byrow = T)
ident <- cbind(ident, ident.3.4)

n <- 5  # 5 Signals
cat("\n------------------------------------------------------------------------------------\n")
cat(" MIX-2: Yonelinas (1994): Exp.3, weak and strong items")
cat("\n------------------------------------------------------------------------------------\n")
Opti3.Obj <- SDT.Estimate(data = data.3, Model.Id = "MIX.2", n = n, fixed = fixed, ident = ident, test = T)
Stat3.Obj <- SDT.Statistics(Opti3.Obj)
print(Stat3.Obj)

# PLOT DENSITY CURVES OF EXP.3
SDT.Plot(Opti3.Obj, cols = rep(1:5, each = 2), ltys = rep(c(1,2), 5), 
SDT.legend = list(text = c("Distractor", "Exclusion Weak", "Inclusion Weak", "Exclusion Strong", "Inclusion Strong"), 
cols = 1:5, pos = c(-4.5, 0.4), ltys = rep(1, 5)))

# PLOT ROC CURVES
# ROC with data
SDT.Plot(Opti3.Obj, cols = c(1, 3, 4, 6), 
SDT.legend = list(text = c("Exclusion Weak", "Inclusion Weak", "Exclusion Strong", "Inclusion Strong"), cols = c(1, 3, 4, 6)), option = "ROC+")

# z-ROC with data
SDT.Plot(Opti3.Obj, cols = c(1, 3, 4, 6), 
SDT.legend = list(text = c("Exclusion Weak", "Inclusion Weak", "Exclusion Strong", "Inclusion Strong"), cols = c(1, 3, 4, 6)), option = "zROC+")