# ================================================================
# MIX-2.5.2: Examples of the documentation of Model MIX.2:
# Modeling the mirror effect
#
# Model: DeCarlo (2007), Model 2
# Data:  Arndt & Reder (2002), Exp.1
#
# Date of creation: May, 2010
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-2.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

n <- 6
# DATA: Arndt & Reder (2002) Exp.1
data <- c( 84, 189, 294, 462, 651, 420,         # High frequency New
           42,  84, 168, 252, 693, 861,         # Low frequency New
          231, 273, 357, 294, 441, 504,         # High frequency similar
          378, 294, 231, 189, 357, 651,         # Low frequency similar
          609, 357, 294, 315, 336, 189,         # High frequency Old
          903, 315, 210, 168, 294, 210)         # Low frequency Old

# DATA MUST BE USED IN REVERSE ORDER
data <- c(rev(data[1:6]), rev(data[7:12]),rev(data[13:18]),rev(data[19:24]),rev(data[25:30]),rev(data[31:36]))

# 1. FIXED CONSTRAINTS		
# 1.1 FIX MEAN OF HIGH FREQUENCY NEW
fixed.m <- matrix(c(0, 0, 
                    2, 4), nr = 2, byrow = T)

# 1.2 FIX SD OF EACH OF THE 12 DISTRIBUTIONS TO 1.0
fixed.sd <- matrix(c(1, 1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
                     3, 5, 13, 15, 23, 25, 33, 35, 43, 45, 53, 55), nr = 2, byrow = T)

# 1.3 FIX PROBABILITY OF HIGH FREQUENCY NEW
fixed.p <- matrix(c(0, 
                    1), nr = 2, byrow = T)

# 1.4 COMBINE FIXED CONSTRAINTS
fixed <- cbind(fixed.m, fixed.sd, fixed.p)


# 2. EQUALITY CONSTRAINTS: IDENTICAL THRESHOLDS FOR ALL SIGNALS
ident <- matrix(c(6:10,       6:10,    6:10,    6:10,    6:10,
	   	      6:10+10, 6:10+20, 6:10+30, 6:10+40, 6:10+50), nr = 2, byrow = T)

cat("\n------------------------------------------------------------------------------------\n")
cat(" MIX-2: Arndt & Reder (2002): Exp.1:")
cat("\n------------------------------------------------------------------------------------\n")
Opti.Obj <- SDT.Estimate(data = data, Model.Id = "MIX.2", n = n, fixed = fixed, ident = ident, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj, dec = 2)
print(Stat.Obj)