# ================================================================
# Examples of the documentation of MIX.2: Plot functions
# MIX-2.6.1: Plotting MIX.2 Model and source monitoring data
#          from Hilford et al. (2002)
#
# Model: Hilford et al. (2002)
# Data:  Hilford et al. (2002), Exp.3
#
# Date of creation: July, 2010
# Autor: Siegfried Macho
# ================================================================

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-2.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# NUMBER OF SIGNALS
n <- 2

# DATA: HILFORD ET AL. (2002), Exp.3
data.3 <- c(1313, 538, 524, 529, 363,  333,		# Top 
 	       348, 356, 455, 552, 510, 1379)		# Bottom


# ESTIMATED PARAMETER-VECTOR
par.vec <-  c(-0.53456675, -1.74495692, 1, 0, 1, -1.05540387, -0.52454507, -0.03075355,  0.51315675, 1.03088702,  # Signal 1
              -0.53456675,  1.74495692, 1, 0, 1, -1.05540387, -0.52454507, -0.03075355,  0.51315675, 1.03088702)  # Signal 2


# PLOT CONFIGURATION USING A LIST WITH CONFIGURATION INFORMATION
Plot.Obj <- list(par = par.vec, n = n, Model.Id = "MIX.2", counts = data.3)

# Plot Density functions
SDT.Plot(Plot.Obj, cols = c(4, 3, 6, 3), SDT.legend = list(text = c("left", "no info", "right"), cols = c(4, 3, 6)))

# Plot ROC without data
SDT.Plot(Plot.Obj, cols = 3, labels = c("False Alarms", "Hits"), option = "ROC")

# Plot ROC with data
SDT.Plot(Plot.Obj, cols = 3, labels = c("False Alarms", "Hits"), option = "ROC+")

# Plot zROC without data
SDT.Plot(Plot.Obj, cols = 3, labels = c("False Alarms", "Hits"), option = "zROC")

# Plot zROC with data
SDT.Plot(Plot.Obj, cols = 3, labels = c("False Alarms", "Hits"), option = "zROC+")