# ================================================================
# Examples of the documentation of MIX.2: Plot functions
# MIX-2.6.3: Plotting MIX.2 Model and data on process dissociation
#
# Model: DeCarlo (2007), Model 2
# Data:  Yonelinas (1994)
#
# Date of creation: July, 2010
# Autor: Siegfried Macho
# ================================================================

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-2.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# NUMBER OF SIGNALS
n <- 5

# DATA: YONELINAS 1994)
data <- c(969, 576, 403, 282, 215, 115,                   # Distractor
          296, 200, 153, 141, 180, 130,                   # Exclusion (weak)
          194, 190, 150, 135, 177, 254,                   # Inclusion (weak)
          351, 170, 150, 120, 162, 187,                   # Exclusion (strong)
          167, 132, 123, 136, 210, 372)                   # Inclusion (strong)

# ESTIMATED PARAMETER-VECTOR
par.vec <-  c(0.00000000,  0.00000000, 1.00000000, 0.00000000, 1.00000000, -0.31174937, 0.27093465, 0.70784212, 1.11176538, 1.71681737,  # Signal 1
             -1.35519425, -0.84721912, 1.00000000, 0.69304320, 1.00000000, -0.31174937, 0.27093465, 0.70784212, 1.11176538, 1.71681737,  # Signal 2
              1.07609670,  0.40398324, 1.00000000, 2.05422266, 1.00000000, -0.31174937, 0.27093465, 0.70784212, 1.11176538, 1.71681737,  # Signal 3
             -0.20701595, -0.55822225, 1.00000000, 1.15330069, 1.00000000, -0.31174937, 0.27093465, 0.70784212, 1.11176538, 1.71681737,  # Signal 5
             -0.77203837, -0.07267485, 1.00000000, 1.61633026, 1.00000000, -0.31174937, 0.27093465, 0.70784212, 1.11176538, 1.71681737)  # Signal 5


# PLOT CONFIGURATION USING A LIST WITH CONFIGURATION INFORMATION
Plot.Obj <- list(par = par.vec, n = n, Model.Id = "MIX.2", counts = data)

# Plot Density functions
SDT.Plot(Plot.Obj, cols = rep(1:5, each = 2), ltys = rep(c(1,2), 5), 
SDT.legend = list(text = c("Distractor", "Exclusion Weak", "Inclusion Weak", "Exclusion Strong", "Inclusion Strong"), 
cols = 1:5, pos = c(-4.5, 0.4), ltys = rep(1, 5)))

# Plot ROC without data
SDT.Plot(Plot.Obj, cols = c(1, 3, 4, 6), 
SDT.legend = list(text = c("Exclusion Weak", "Inclusion Weak", "Exclusion Strong", "Inclusion Strong"), cols = c(1, 3, 4, 6)), option = "ROC")

# Plot ROC with data
SDT.Plot(Plot.Obj, cols = c(1, 3, 4, 6), 
SDT.legend = list(text = c("Exclusion Weak", "Inclusion Weak", "Exclusion Strong", "Inclusion Strong"), cols = c(1, 3, 4, 6)), option = "ROC+")

# Plot zROC without data
SDT.Plot(Plot.Obj, cols = c(1, 3, 4, 6), 
SDT.legend = list(text = c("Exclusion Weak", "Inclusion Weak", "Exclusion Strong", "Inclusion Strong"), cols = c(1, 3, 4, 6)), option = "zROC")

# Plot zROC with data
SDT.Plot(Plot.Obj, cols = c(1, 3, 4, 6), 
SDT.legend = list(text = c("Exclusion Weak", "Inclusion Weak", "Exclusion Strong", "Inclusion Strong"), cols = c(1, 3, 4, 6)), option = "zROC+")

