# ================================================================
# Examples of the documentation of MIX.2: Plot functions
# MIX-2.6.4: Plotting MIX.2 Model and data of the Mirror Effect
#
# Model: DeCarlo (2007), Model 2
# Data: DeCarlo (2007)
#
# Date of creation: July, 2010
# Autor: Siegfried Macho
# ================================================================

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-2.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# NUMBER OF SIGNALS
n <- 4

# DATA: DeCARLO (2007) Exp.1A: NATIVE SPEAKERS
data.1A <- c( 721, 1418, 1460,  860, 422,  159,        # High frequency New
             1457, 1436,  991,  567, 398,  191,        # Low frequency New
              211,  689, 1016, 1028, 894, 1202,        # High frequency Old
              233,  457,  568,  729, 995, 2058)        # Low frequency Old

# ESTIMATED PARAMETER-VECTOR
par.vec <-  c( 0.0000000, 0.0000000,  1.0000000,  0.0000000,  1.0000000, -1.0730092, -0.1809085,  0.5557307,  1.1951579,  1.8795694,  # Signal 1
              -0.8612194, 0.7410640,  1.0000000, -0.8162561,  1.0000000, -1.0730092, -0.1809085,  0.5557307,  1.1951579,  1.8795694,  # Signal 2
              -0.8070838, 2.1033197,  1.0000000,  0.4870771,  1.0000000, -1.0730092, -0.1809085,  0.5557307,  1.1951579,  1.8795694,  # Signal 3
              -1.0806819,-0.1588116,  1.0000000,  1.9785886,  1.0000000, -1.0730092, -0.1809085,  0.5557307,  1.1951579,  1.8795694)  # Signal 4

# PLOT CONFIGURATION USING A LIST WITH CONFIGURATION INFORMATION
Plot.Obj <- list(par = par.vec, n = n, Model.Id = "MIX.2", counts = data.1A)

# Plot Density functions
SDT.Plot(Plot.Obj, cols = rep(1:4, each = 2), ltys = rep(c(1,2), 4), 
SDT.legend = list(text = c("HF", "LF New", "HF Old", "LF Old"), cols = 1:4, ltys = rep(1, 4)))

# Plot ROC without data
SDT.Plot(Plot.Obj, cols = c(3, 4, 6), 
SDT.legend = list(text = c("LF New", "HF Old", "LF Old"), cols = c(3, 4, 6)), option = "ROC")

# Plot ROC with data
SDT.Plot(Plot.Obj, cols = c(3, 4, 6), 
SDT.legend = list(text = c("LF New", "HF Old", "LF Old"), cols = c(3, 4, 6)), option = "ROC+")

# Plot zROC without data
SDT.Plot(Plot.Obj, cols = c(3, 4, 6), 
SDT.legend = list(text = c("LF New", "HF Old", "LF Old"), cols = c(3, 4, 6)), option = "zROC")

# Plot zROC with data
SDT.Plot(Plot.Obj, cols = c(3, 4, 6), 
SDT.legend = list(text = c("LF New", "HF Old", "LF Old"), cols = c(3, 4, 6)), option = "zROC+")