# ================================================================
# MIX-2.7: Examples of the documentation of Model MIX-2:
# Rating data for two signals (6 categories)
# Standard mixture and extended mixture models are fitted
#
# Date of creation: April, 2014
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource  <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/"
DirSourceM <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL
Model <- "SDT-MIX-2.R"

# FILE NAMES FOR ESTIMATION
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# DATA FROM AN OWN EXPERIMENT
datavec <- c(612, 752, 636, 383, 316, 181,            # New
             155, 261, 351, 367, 495, 1251)           # Old

# NUMBER OF CONDITIONS (TYPES OF SIGNALS)
n <- 2

# Fixed and identity constraints
# FIXED CONSTRAINTS OF STANDARD MODEL
fixed.st <- matrix(c(0, 0, 1, 0, 1,  1,  0,  1,
                     1, 2, 3, 4, 5, 13, 14, 15), nr = 2, byrow = T)
                  
# FIXED CONSTRAINTS OF EXTENDED MODEL
fixed.ex <- matrix(c(0, 0, 1, 0, 1,  1,  1,
                     1, 2, 3, 4, 5, 13, 15), nr = 2, byrow = T)

# EQUALITY CONSTRAINTS ON THRESHOLDS
ident    <- matrix(c( 6:10,
                     16:20), nr = 2, byrow = T)

cat("\n---------------------------------------------------------------------\n")
cat(" MIX-2: Parameter information (STANDARD restrictions):")
cat("\n Model: Rating data for 2 signals (6 Ratings):")
cat("\n---------------------------------------------------------------------\n")
Par.Info <- SDT.Parameter.Info (data = datavec, Model.Id = "MIX.2", n = n, fixed = fixed.st, ident = ident)
print(Par.Info)

cat("\n---------------------------------------------------------------------\n")
cat(" MIX-2: Parameter information (EXTENDED restrictions):")
cat("\n Model: Rating data for 2 signals (6 Ratings):")
cat("\n---------------------------------------------------------------------\n")
Par.Info <- SDT.Parameter.Info (data = datavec, Model.Id = "MIX.2", n = n, fixed = fixed.ex, ident = ident)
print(Par.Info)

cat("\n---------------------------------------------------------------------\n")
cat(" MIX-2: Estimation of STANDARD model:")
cat("\n---------------------------------------------------------------------\n")
Opti1.Obj <- SDT.Estimate(data = datavec, n = n, Model.Id = "MIX.2", fixed = fixed.st, ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

cat("\n---------------------------------------------------------------------\n")
cat(" MIX-2: Estimation of EXTENDED model:")
cat("\n---------------------------------------------------------------------\n")
Opti2.Obj <- SDT.Estimate(data = datavec, n = n, Model.Id = "MIX.2", fixed = fixed.ex, ident = ident, test = T)
Stat2.Obj <- SDT.Statistics(Opti2.Obj)
print(Stat2.Obj)

