# ================================================================
# Ex.0: MIX-Bias-Rank model
#       Demonstration of standard restrictions
# 
# Date of creation: July, 2013
# Autor: Siegfried Macho
# ================================================================

# Names of directories: PLEASE ADJUST TO YOUR PERSONAL SETTING
Dir  <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"
DirM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# Names of the source files required for estimating the data
NameS <- "SDT-Main.R"
NameA <- "SDT-Auxiliary.R"
NameM <- "MIX-Bias-Rank.R"
# Load source files
source(paste(Dir,  NameA, sep = ""))
source(paste(Dir,  NameS, sep = ""))
source(paste(DirM, NameM, sep = ""))


#===============================================================================
# 1. Standard restrictions
#===============================================================================

cat("\n--------------------------------------------------\n")
cat(" Configuration 1-1 (Standard restrictions):\n")
cat(" cfg = list(j.rg = 4, rating = F)")
cat("\n--------------------------------------------------\n")
cfg <- list(j.rg = 4, rating = F)
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "MIX.Bias.Rank")
print(Erg)

cat("\n--------------------------------------------------\n")
cat(" Configuration 1-2 (Standard restrictions):\n")
cat(" cfg = list(j.rg = c(4, 3, 2), rating = F)")
cat("\n--------------------------------------------------\n")
cfg <- list(j.rg = c(4, 3, 2), rating = F)
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "MIX.Bias.Rank")
print(Erg)

cat("\n------------------------------------------------------------------\n")
cat(" Configuration 1-3  (Standard restrictions)[ 6 Response categories]:\n")
cat(" cfg = list(n.sdt = 2, j.rg = c(4, 3), k.rg = c(4, 3), rating = T)")
cat("\n------------------------------------------------------------------\n")
cfg <- list(n.sdt = 2, j.rg = c(4, 3), k.rg = c(4, 3), rating = T)
datavec <- rep(0, sum(cfg$j.rg*cfg$k.rg) + cfg$n.sdt*6)
Erg <- SDT.Parameter.Info(data = datavec, n = cfg, Model.Id = "MIX.Bias.Rank")
print(Erg)

#===============================================================================
# 2. SDT restrictions
#===============================================================================

cat("\n--------------------------------------------------\n")
cat(" Configuration 2-1 (SDT restrictions):\n")
cat(" cfg = list(j.rg = 4, rating = F)")
cat("\n--------------------------------------------------\n")
cfg <- list(j.rg = 4, rating = F, restriction = "SDT")
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "MIX.Bias.Rank")
print(Erg)

cat("\n--------------------------------------------------\n")
cat(" Configuration 2-2 (SDT restrictions):\n")
cat(" cfg = list(j.rg = c(4, 3, 2), rating = F)")
cat("\n--------------------------------------------------\n")
cfg <- list(j.rg = c(4, 3, 2), rating = F, restriction = "SDT")
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "MIX.Bias.Rank")
print(Erg)

cat("\n------------------------------------------------------------------\n")
cat(" Configuration 2-3  (SDT restrictions)[ 6 Response categories]:\n")
cat(" cfg = list(n.sdt = 2, j.rg = c(4, 3), k.rg = c(4, 3), rating = T)")
cat("\n------------------------------------------------------------------\n")
cfg <- list(n.sdt = 2, j.rg = c(4, 3), k.rg = c(4, 3), rating = T, restriction = "SDT")
datavec <- rep(0, sum(cfg$j.rg*cfg$k.rg) + cfg$n.sdt*6)
Erg <- SDT.Parameter.Info(data = datavec, n = cfg, Model.Id = "MIX.Bias.Rank")
print(Erg)

#===============================================================================
# 3. Extended restrictions
#===============================================================================

cat("\n--------------------------------------------------\n")
cat(" Configuration 3-1 (extended restrictions):\n")
cat(" cfg = list(j.rg = 4, rating = F)")
cat("\n--------------------------------------------------\n")
cfg <- list(j.rg = 4, rating = F, restriction = "extended")
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "MIX.Bias.Rank")
print(Erg)

cat("\n--------------------------------------------------\n")
cat(" Configuration 3-2 (extended restrictions):\n")
cat(" cfg = list(j.rg = c(4, 3, 2), rating = F)")
cat("\n--------------------------------------------------\n")
cfg <- list(j.rg = c(4, 3, 2), rating = F, restriction = "extended")
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "MIX.Bias.Rank")
print(Erg)

cat("\n----------------------------------------------------------------------\n")
cat(" Configuration 3-3  (extended restrictions)[ 6 Response categories]:\n")
cat(" cfg = list(n.sdt = 2, j.rg = c(4, 3), k.rg = c(4, 3), rating = T)")
cat("\n----------------------------------------------------------------------\n")
cfg <- list(n.sdt = 2, j.rg = c(4, 3), k.rg = c(4, 3), rating = T, restriction = "extended")
datavec <- rep(0, sum(cfg$j.rg*cfg$k.rg) + cfg$n.sdt*6)
Erg <- SDT.Parameter.Info(data = datavec, n = cfg, Model.Id = "MIX.Bias.Rank")
print(Erg)