# ==============================================================================
# Ex.2: MIX-Bias-Rank model
#       Estimation of the ranking-rating model (ranking & rating, single model)
# Data: From own experiment
#
# Date of creation: July, 2013
# Autor: Siegfried Macho
# ==============================================================================

# Names of directories: PLEASE ADJUST TO YOUR PERSONAL SETTING
Dir  <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"
DirM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# Names of the source files required for estimating the data
NameS <- "SDT-Main.R"
NameA <- "SDT-Auxiliary.R"
NameM <- "MIX-Bias-Rank.R"

# Load source files
source(paste(Dir,  NameA, sep = ""))
source(paste(Dir,  NameS, sep = ""))
source(paste(DirM, NameM, sep = ""))

# DATA:
datavec <- c(210,  68,  68,  54,            # Ranking, Target on Position 1
             193,  98,  60,  49,            # Ranking, Target on Position 2
             198, 101,  55,  46,            # Ranking, Target on Position 3
             169,  88,  82,  61,            # Ranking, Target on Position 4
             
             432, 341, 309, 262, 185,  71,  # Rating data (new)
             179, 220, 238, 256, 257, 450)  # Rating data (old)

#===============================================================================
# 1. Estimation of rating and ranking data: Standard configuration
#===============================================================================
cfg <- list(k.rg = 4)

ptm1 <- proc.time()

Opti1.Obj <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "MIX.Bias.Rank", test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)			# Evaluate the results

cat("\n----------------------------------------------------------------------------\n")
cat("Test 1: MIX-Bias: Ranking and ranking\n")
cat("        Standard restrictions")
cat("\n-----------------------------------------------------------------------------\n")
print(Stat1.Obj)

ptm2 <- proc.time()                       # Measuring time elapsed
tm <- time.estimate(ptm1, ptm2)
cat("\n=======================================================\n")
cat("Time required:\n")
cat(tm[1], "hours,", tm[2], "minutes,", tm[3], "seconds")
cat("\n=======================================================\n")


#===============================================================================
# 2. Estimation of rating and ranking data: Unequal variance SDT model
#===============================================================================
cfg <- list(k.rg = 4, restriciton = "SDT")

Opti2.Obj <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "MIX.Bias.Rank", test = T)
Stat2.Obj <- SDT.Statistics(Opti2.Obj)			# Evaluate the results

cat("\n----------------------------------------------------------------------------\n")
cat("Test 2: MIX-Bias: Ranking and ranking\n")
cat("        Unequal variance SDT model")
cat("\n-----------------------------------------------------------------------------\n")
print(Stat2.Obj)


ptm3 <- proc.time()                       # Measuring time elapsed
tm <- time.estimate(ptm2, ptm3)
cat("\n=======================================================\n")
cat("Time required (for SDT model with bias):\n")
cat(tm[1], "hours,", tm[2], "minutes,", tm[3], "seconds")
cat("\n=======================================================\n")


#===============================================================================
# 3. Estimation of rating and ranking data: Extended mixture model
#===============================================================================
cfg <- list(k.rg = 4, restriction = "EXTENDED")

Opti3.Obj <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "MIX.Bias.Rank", test = T)
Stat3.Obj <- SDT.Statistics(Opti3.Obj)			# Evaluate the results

cat("\n----------------------------------------------------------------------------\n")
cat("Test 2: MIX-Bias: Ranking and ranking\n")
cat("        Unequal variance SDT model")
cat("\n-----------------------------------------------------------------------------\n")
print(Stat3.Obj)


ptm4 <- proc.time()                       # Measuring time elapsed
tm <- time.estimate(ptm3, ptm4)
cat("\n=======================================================\n")
cat("Time required (for EXTENDED mixture model with bias):\n")
cat(tm[1], "hours,", tm[2], "minutes,", tm[3], "seconds")
cat("\n=======================================================\n")
