# ================================================================
# Examples of the documentation of Model MIX.PD:
# MIX.1-1: Source monitoring with 2 signals
# Data from DeCarlo (2003)
# Date of creation: July, 2009
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-PD.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# DATA OF DeCARLO(2003): Exp. 1: 1 sec left, 1 sec right

data.1 <- c(226, 101, 118, 136, 100,  39,		# Source A: left
		 45,  84, 123, 147, 118, 203)		# Source B: right


# DATA OF DeCARLO(2003): Exp. 1: 3 sec left, 3 sec right
data.2 <- c(261, 126, 126, 102,  78,  27,		# Source A: left
		 42,  77, 105, 111, 127, 258)		# Source B: right

# DATA OF DeCARLO(2003): Exp. 1: 3 sec left, 1 sec right
data.3 <- c(205, 138, 131, 117,  85,  44,		# Source A: left
		 30, 101, 111, 170, 144, 164)		# Source B: right


# DATA OF DeCARLO(2003): Exp. 1: 1 sec left, 3 sec right
data.4 <- c(281, 125, 118,  88,  64,  44,		# Source A: left
		 28,  59,  85, 105, 117, 326)		# Source B: right

# SPECIFY EQUALITY CONSTRAINTS:
ident <- matrix(c( 1, 3,					# d'.left  = d'.right, p.left  = p.right
	   	       2, 4), nr = 2, byrow = T)
ident.d <- matrix(c(3, 4), nr = 2)				# d'.left  = d'.right, p.left <> p.right
ident.p <- matrix(c(1, 2), nr = 2)				# d'.left <> d'.right, p.left  = p.right

cat("\n-------------------------------------------------------------------------\n")
cat(" MIX.PD: Source Monitoring Model of DeCarlo (2003): 1 s left, 1 s right")
cat("\n d'left = d'.right, p.left = p.right")
cat("\n-------------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti1.Obj <- SDT.Estimate(data = data.1, Model.Id = "MIX.PD", ident = ident, test = T)

Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

cat("\n-------------------------------------------------------------------------\n")
cat(" MIX.PD: Source Monitoring Model of DeCarlo (2003): 3 s left, 3 s right")
cat("\n d'left = d'.right, p.left = p.right")
cat("\n-------------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti2.Obj <- SDT.Estimate(data = data.2, Model.Id = "MIX.PD", ident = ident, test = T)

Stat2.Obj <- SDT.Statistics(Opti2.Obj)
print(Stat2.Obj)

cat("\n-------------------------------------------------------------------------\n")
cat(" MIX.PD: Source Monitoring Model of DeCarlo (2003): 3 s left, 1 s right")
cat("\n d'left = d'.right, p.left = p.right")
cat("\n-------------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti3.Obj <- SDT.Estimate(data = data.3, Model.Id = "MIX.PD", ident = ident, test = T)

Stat3.Obj <- SDT.Statistics(Opti3.Obj)
print(Stat3.Obj)

cat("\n-------------------------------------------------------------------------\n")
cat(" MIX.PD: Source Monitoring Model of DeCarlo (2003): 3 s left, 1 s right")
cat("\n d'left = d'.right, p.left <> p.right")
cat("\n-------------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti3.1.Obj <- SDT.Estimate(data = data.3, Model.Id = "MIX.PD", ident = ident.d, test = T)

Stat3.1.Obj <- SDT.Statistics(Opti3.1.Obj)
print(Stat3.1.Obj)

cat("\n-------------------------------------------------------------------------\n")
cat(" MIX.PD: Source Monitoring Model of DeCarlo (2003): 3 s left, 1 s right")
cat("\n d'left <> d'.right, p.left = p.right")
cat("\n-------------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti3.2.Obj <- SDT.Estimate(data = data.3, Model.Id = "MIX.PD", ident = ident.p, test = T)

Stat3.2.Obj <- SDT.Statistics(Opti3.2.Obj)
print(Stat3.2.Obj)

cat("\n-------------------------------------------------------------------------\n")
cat(" MIX.PD: Source Monitoring Model of DeCarlo (2003): 1 s left, 3 s right")
cat("\n d'left = d'.right, p.left = p.right")
cat("\n-------------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti4.Obj <- SDT.Estimate(data = data.4, Model.Id = "MIX.PD", ident = ident, test = T)

Stat4.Obj <- SDT.Statistics(Opti4.Obj)
print(Stat4.Obj)

cat("\n-------------------------------------------------------------------------\n")
cat(" MIX.PD: Source Monitoring Model of DeCarlo (2003): 3 s left, 1 s right")
cat("\n d'left = d'.right, p.left <> p.right")
cat("\n-------------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti4.1.Obj <- SDT.Estimate(data = data.4, Model.Id = "MIX.PD", ident = ident.d, test = T)

Stat4.1.Obj <- SDT.Statistics(Opti4.1.Obj)
print(Stat4.1.Obj)
cat("\n-------------------------------------------------------------------------\n")
cat(" MIX.PD: Source Monitoring Model of DeCarlo (2003): 1 s left, 3 s right")
cat("\n d'left <> d'.right, p.left = p.right")
cat("\n-------------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti4.2.Obj <- SDT.Estimate(data = data.4, Model.Id = "MIX.PD", ident = ident.p, test = T)

Stat4.2.Obj <- SDT.Statistics(Opti4.2.Obj)
print(Stat4.2.Obj)