# ================================================================
# Examples of the documentation of Model MIX-PD:
# MIX-PD.1-2: Source monitoring with two signals
# Data from Hilford et al. (2002)
#
# Date of creation: July, 2009
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-PD.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))


# DATA: HILFORD ET AL. (2002), Exp.1
data.1 <- c(264, 133, 159, 116,  80,  33,			# Male voice 
 	       25,  62, 105, 128, 145, 294)			# Female voice


# DATA: HILFORD ET AL. (2002), Exp.2
data.2 <- c(1358, 550, 701, 585, 466,  300,		# Male
 	       278, 477, 598, 614, 589, 1404)		# Female


# DATA: HILFORD ET AL. (2002), Exp.3
data.3 <- c(1313, 538, 524, 529, 363,  333,		# Top 
 	       348, 356, 455, 552, 510, 1379)		# Bottom


# SPECIFY EQUALITY CONSTRAINTS: IDENTICAL PROBABILITIES AND d'
ident <- matrix(c( 1, 3,
	   	       2, 4), nr = 2, byrow = T)

cat("\n------------------------------------------------------------------------------------\n")
cat(" MIX-PD: Hilford et al. (2002): Exp.1")
cat("\n------------------------------------------------------------------------------------\n")
# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti1.Obj <- SDT.Estimate(data = data.1, Model.Id = "MIX.PD", ident = ident, test = T)
Stat1.Obj <- SDT.Statistics(Opti1.Obj)
print(Stat1.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" MIX-PD: Hilford et al. (2002): Exp.2")
cat("\n------------------------------------------------------------------------------------\n")
# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti2.Obj <- SDT.Estimate(data = data.2, Model.Id = "MIX.PD", ident = ident, test = T)
Stat2.Obj <- SDT.Statistics(Opti2.Obj)
print(Stat2.Obj)

cat("\n------------------------------------------------------------------------------------\n")
cat(" MIX-PD: Hilford et al. (2002): Exp.3")
cat("\n------------------------------------------------------------------------------------\n")
# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti3.Obj <- SDT.Estimate(data = data.3, Model.Id = "MIX.PD", ident = ident, test = T)
Stat3.Obj <- SDT.Statistics(Opti3.Obj)
print(Stat3.Obj)

# PLOT GAUSSIAN DISTRIBUTIONS AND THRESHOLDS, AS WELL AS ROC CURVES FOR EXP.3:
# PLOT DENSITY CURVES
SDT.Plot(Opti3.Obj, cols = c(3, 4, 6), SDT.legend = list(text = c( "no info", "left",  "right")))

# PLOT ROC CURVES
# Plot ROC curve with data
SDT.Plot(Opti3.Obj, cols = 3, labels = c("False Alarms", "Hits"), option = "ROC+")

# Plot z-ROC curve with data
SDT.Plot(Opti3.Obj, cols = 3, labels = c("z(FA)", "z(H)"), option = "zROC+")