# ================================================================
# Examples of the documentation of Model MIX-PD:
# MIX-PD.2-1: Modeling Associative Recognition
# Data from Kelley and Wixted, Exp.1
#
# Date of creation: August, 2009
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-PD.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))


# DATA OF KELLEY & WIXTED (2001), Experiment 1
data <- c(198, 148, 210,  85,  49,  30,   # Weak   Items, rearranged
	     72,  91, 167,  71,  71, 248,	# Weak   Items, intact
	    305, 110, 126,  79,  45,  55,	# Strong Items, rearranged
	     19,  23,  36,  57,  81, 504) 	# Strong Items, intact

# NUMBER OF CONDITIONS (TYPES OF SIGNALS)
n <- 4		

# IDENTITY CONSTRAINTS. p.left = p.right, d'.left = d'.right
ident <- matrix(c(1, 3, 1+6, 3+6,
	   	      2, 4, 2+6, 4+6), nr = 2, byrow = T)

# IDENTITY CONSTRAINTS. d'.left = d'.right
ident.d <- matrix(c(3, 3+6,
	   	        4, 4+6), nr = 2, byrow = T)

# IDENTITY CONSTRAINTS. d'.left = d'.right (strong = weak)
ident.d.w.s <- matrix(c(3, 3,     3,
	     	            4, 3+6, 4+6), nr = 2, byrow = T)

cat("\n--------------------------------------------------------------------\n")
cat(" MIX.PD: Associative recognition (Data from Kelley and Wixted, Exp.1:")
cat("\n p.left  = p.right, d'.left  = d'.right") 
cat("\n--------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti.Obj <- SDT.Estimate(data = data, Model.Id = "MIX.PD", n = n, ident = ident, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)
print(Stat.Obj)

cat("\n--------------------------------------------------------------------\n")
cat(" MIX.PD: Associative recognition (Data from Kelley and Wixted, Exp.1):")
cat("\n p.left  <> p.right, d'.left  = d'.right") 
cat("\n--------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti.Obj <- SDT.Estimate(data = data, Model.Id = "MIX.PD", n = n, ident = ident.d, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)
print(Stat.Obj)

cat("\n--------------------------------------------------------------------\n")
cat(" MIX.PD: Associative recognition (Data from Kelley and Wixted, Exp.1):")
cat("\n p.left  <> p.right, d'.left  = d'.right (weak = strong)") 
cat("\n--------------------------------------------------------------------\n")

# ESTIMATE THE MODEL AND EVALUATE THE RESULT
Opti.Obj <- SDT.Estimate(data = data, Model.Id = "MIX.PD", n = n, ident = ident.d.w.s, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)
print(Stat.Obj)

cat("\n---------------------------------------------------------------------------------------------\n")
cat(" MIX-PD: Associative recognition (Data from Kelley and Wixted, Exp.1): Parameter Information")
cat("\n--------------------------------------------------------------------------------------------\n")
# COMPUTE AND PRINT PARAMETER INFORMATION
pinfo <- SDT.Parameter.Info(data = Opti.Obj$SDT.data, par = Opti.Obj$SDT.full.par, n = Opti.Obj$SDT.n, Model.Id = Opti.Obj$SDT.Model.Id, 
                              fixed = Opti.Obj$SDT.fixed, ident = Opti.Obj$SDT.ident)
print(pinfo)

# PLOT RESULTS
SDT.Plot(Opti.Obj, cols = c(3, 3, 3, 4, 4, 4), SDT.legend = list(text = c(paste("weak", 1:3),paste("strong", 1:3))))