# ================================================================
# Examples of the documentation of Model MIX.PD:  Plot functions
# MIX.PD.4-1: Plot of Density and ROC curves 
#
# Data: DeCarlo (2003) Source monitoring with 2 signals
#
# Date of creation: July, 2010
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-PD.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# DATA OF DeCARLO(2003): Exp. 1: 1 sec left, 3 sec right
n <- 2
data <- c(281, 125, 118,  88,  64,  44,		# Source A: left
           28,  59,  85, 105, 117, 326)		# Source B: right

# VECTOR OF ESTIMATED PARAMETERS
par.vec <- c( 0.06946587,  0.06946587,  1.85063699,  1.85063699, 
             -1.39124338, -0.70940186, -0.07232018,  0.52170423,  1.15018812)

# PLOT CONFIGURATION OF DENSITY CURVES AND ROC CURVES USING A LIST WITH CONFIGURATION INFORMATION
Plot.Obj <- list(par = par.vec, n = n, Model.Id = "MIX.PD", counts = data)

# Plot Density functions
SDT.Plot(Plot.Obj, cols = c(3, 4, 6), SDT.legend = list(text = c("no info", "left",  "right")))

# Plot ROC without data
SDT.Plot(Plot.Obj, cols = 3, labels = c("False Alarms", "Hits"), option = "ROC")

# Plot ROC with data
SDT.Plot(Plot.Obj, cols = 3, labels = c("False Alarms", "Hits"), option = "ROC+")

# Plot zROC without data
SDT.Plot(Plot.Obj, cols = 3, labels = c("False Alarms", "Hits"), option = "zROC")

# Plot zROC with data
SDT.Plot(Plot.Obj, cols = 3, labels = c("False Alarms", "Hits"), option = "zROC+")
