# ================================================================
# Examples of the documentation of Model MIX.PD:  Plot functions
# MIX.PD.4-3: Plot of Density and ROC curves 
#
# Data: Kelley & Wixted (2001), Exp.2: Associative Recognition
#
# Date of creation: July, 2010
# Author: Siegfried Macho
# ================================================================
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-MIX-PD.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# NUMBER OF SIGNALS
n <- 5

# DATA OF KELLEY & WIXTED (2001), Experiment 2
data <- c(879, 553, 345,  61,  54,  28,	# Exp.2: Lure items
	    179, 109,  82,  45,  28,  37,   # Exp.2: Weak   Items, rearranged
	     81,  69,  62,  31,  37, 200,	# Exp.2: Weak   Items, intact
	    215,  82,  60,  31,  31,  61,	# Exp.2: Strong Items, rearranged
 	     21,  24,  33,  21,  33, 348)	# Exp.2: Strong Items, intact
	       
# VECTOR OF ESTIMATED PARAMETERS
par.vec <- c(0.5085119,  1.2375336, -2.2133346, -0.1546351,  2.7197003,  2.7197003,
             0.8496212,  1.4752775, -0.8198382,  1.6792104,  2.7197003,  2.7197003,
            -0.1078434,  0.6754557,  1.4018938,  1.7458245,  2.1873065)

# PLOT CONFIGURATION OF DENSITY CURVES AND ROC CURVES USING A LIST WITH CONFIGURATION INFORMATION
Plot.Obj <- list(par = par.vec, n = n, Model.Id = "MIX.PD", counts = data)

# Plot Density functions
SDT.Plot(Plot.Obj, cols = c(6, 3, 3, 3, 4, 4, 4), 
SDT.legend = list(text = c("New", paste("Weak", 1:3),paste("Strong", 1:3)), cols = c(6, 3, 3, 3, 4, 4, 4)))

# Plot ROC without data
SDT.Plot(Plot.Obj, cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1), labels = c("False Alarms", "Hits"), option = "ROC",
SDT.legend = list(text = c("weak rearranged", "weak intact","strong rearranged", "strong intact"), cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1)))

# Plot ROC with data
SDT.Plot(Plot.Obj, cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1), labels = c("False Alarms", "Hits"), option = "ROC+",
SDT.legend = list(text = c("weak rearranged", "weak intact","strong rearranged", "strong intact"), cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1)))

# Plot zROC without data
SDT.Plot(Plot.Obj, cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1), labels = c("False Alarms", "Hits"), option = "zROC",
SDT.legend = list(text = c("weak rearranged", "weak intact","strong rearranged", "strong intact"), cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1)))

# Plot zROC with data
SDT.Plot(Plot.Obj, cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1), labels = c("False Alarms", "Hits"), option = "zROC+",
SDT.legend = list(text = c("weak rearranged", "weak intact","strong rearranged", "strong intact"), cols = c(3, 3, 4, 4), ltys = c(2, 1, 2, 1)))
