# ================================================================
# Ex.0: MIX-Rank model
#       Demonstration of standard restrictions
# 
# Date of creation: June, 2013
# Autor: Siegfried Macho
# ================================================================

# Names of directories: PLEASE ADJUST TO YOUR PERSONAL SETTING
Dir  <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"
DirM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# Names of the source files required for estimating the data
NameS <- "SDT-Main.R"
NameA <- "SDT-Auxiliary.R"
NameM <- "MIX-Rank.R"
# Load source files
source(paste(Dir,  NameA, sep = ""))
source(paste(Dir,  NameS, sep = ""))
source(paste(DirM, NameM, sep = ""))

#============================================================
# 1. Setting standard restrictions
#============================================================

cat("\n--------------------------------------------------\n")
cat(" MIX.Rank: Standard restrictions:\n")
cat(" Configuration 1:\n")
cat(" cfg = list(j.rg = 4, rating = F)")
cat("\n--------------------------------------------------\n")
cfg <- list(j.rg = 4, rating = F)
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "MIX.Rank")
print(Erg)

cat("\n--------------------------------------------------\n")
cat(" MIX.Rank: Standard restrictions:\n")
cat(" Configuration 2:\n")
cat(" cfg = list(j.rg = c(4, 3, 2), rating = F)")
cat("\n--------------------------------------------------\n")
cfg <- list(j.rg = c(4, 3, 2), rating = F)
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "MIX.Rank")
print(Erg)

cat("\n--------------------------------------------------\n")
cat(" MIX.Rank: Standard restrictions:\n")
cat(" Configuration 3: [6 Rating Response categories]\n")
cat(" cfg = list(j.rg = c(4, 3), rating = T)")
cat("\n--------------------------------------------------\n")
datavec <- rep(0, 19)
cfg <- list(j.rg = c(4, 3), rating = T)
Erg <- SDT.Parameter.Info(data = datavec, n = cfg, Model.Id = "MIX.Rank")
print(Erg)


#============================================================
# 2. Setting SDT restrictions: Unequal variance model
#============================================================

cat("\n--------------------------------------------------\n")
cat(" MIX.Rank: Unequal variance SDT restrictions:\n")
cat(" Configuration 1:\n")
cat(" cfg = list(j.rg = 4, rating = F, restriction = \"SDT\")")
cat("\n--------------------------------------------------\n")
cfg <- list(j.rg = 4, rating = F, restriction = "SDT")
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "MIX.Rank")
print(Erg)

cat("\n----------------------------------------------------------------------\n")
cat(" MIX.Rank: Unequal variance SDT restrictions:\n")
cat(" Configuration 2:\n")
cat(" cfg = list(j.rg = c(4, 3, 2), rating = F, restriction = \"SDT\")")
cat("\n----------------------------------------------------------------------\n")
cfg <- list(j.rg = c(4, 3, 2), rating = F, restriction = "SDT")
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "MIX.Rank")
print(Erg)

cat("\n----------------------------------------------------------------------\n")
cat(" MIX.Rank: Unequal variance SDT restrictions:\n")
cat(" Configuration 3: [6 Rating Response categories]\n")
cat(" cfg = list(j.rg = c(4, 3), rating = T, restriction = \"SDT\")")
cat("\n----------------------------------------------------------------------\n")
datavec <- rep(0, 19)
cfg <- list(j.rg = c(4, 3), rating = T, restriction = "SDT")
Erg <- SDT.Parameter.Info(data = datavec, n = cfg, Model.Id = "MIX.Rank")
print(Erg)


#============================================================
# 3. Setting SDT restrictions: Extended mixture model
#============================================================

cat("\n--------------------------------------------------\n")
cat(" MIX.Rank: Extended mixture model weak mean <> 0:\n")
cat(" Configuration 1:\n")
cat(" cfg = list(j.rg = 4, rating = F, restriction = \"extended\")")
cat("\n--------------------------------------------------\n")
cfg <- list(j.rg = 4, rating = F, restriction = "extended")
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "MIX.Rank")
print(Erg)

cat("\n----------------------------------------------------------------------\n")
cat(" MIX.Rank: Extended mixture model weak mean <> 0:\n")
cat(" Configuration 2:\n")
cat(" cfg = list(j.rg = c(4, 3, 2), rating = F, restriction = \"extended\")")
cat("\n----------------------------------------------------------------------\n")
cfg <- list(j.rg = c(4, 3, 2), rating = F, restriction = "extended")
Erg <- SDT.Parameter.Info(n = cfg, Model.Id = "MIX.Rank")
print(Erg)

cat("\n----------------------------------------------------------------------\n")
cat(" MIX.Rank: Extended mixture model weak mean <> 0:\n")
cat(" Configuration 3: [6 Rating Response categories]\n")
cat(" cfg = list(j.rg = c(4, 3), rating = T, restriction = \"extended\")")
cat("\n----------------------------------------------------------------------\n")
datavec <- rep(0, 19)
cfg <- list(j.rg = c(4, 3), rating = T, restriction = "extended")
Erg <- SDT.Parameter.Info(data = datavec, n = cfg, Model.Id = "MIX.Rank")
print(Erg)
