# ================================================================
# Ex.1: MIX-Rank model
# Estimation of the ranking-rating model
# Data: Kellen Klauer and Singmann(2012)
#
# Date of creation: July, 2013
# Autor: Siegfried Macho
# ================================================================

# Names of directories: PLEASE ADJUST TO YOUR PERSONAL SETTING
Dir  <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"
DirM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# Names of the source files required for estimating the data
NameS <- "SDT-Main.R"
NameA <- "SDT-Auxiliary.R"
NameM <- "MIX-Rank.R"

# Load source files
source(paste(Dir,  NameA, sep = ""))
source(paste(Dir,  NameS, sep = ""))
source(paste(DirM, NameM, sep = ""))

# Data vector of Kellen, Klauer & Singmann (2012), pooled data
datavec <- c(1801, 488, 407, 304,                 # 1. Ranking data
              667, 780, 651, 485, 277,  140,      # 2. Rating data (new)
              198, 303, 402, 421, 426, 1250)      # 3. Rating data (old)

#===============================================================================
# 1. Estimation of ranking data only
#===============================================================================
cfg <- list(k.rg = 4, rating = F)

Opti.Obj <- SDT.Estimate(data = datavec[1:4], n = cfg, Model.Id = "MIX.Rank", test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results
cat("\n-------------------------------------------------------------------------\n")
cat(" MIX-Rank 1:\n")
cat(" Results of Kellen, Klauer & Singmann, 2012: ranking data only")
cat("\n-------------------------------------------------------------------------\n")
print(Stat.Obj)

#===============================================================================
# 2. Estimation of both ranking and rating data
#===============================================================================
cfg <- list(k.rg = 4, rating = T)

Opti.Obj <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "MIX.Rank", test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results
cat("\n--------------------------------------------------------------------------\n")
cat(" MIX-Rank 2:\n")
cat(" Results of Kellen, Klauer & Singmann, 2012: ranking and rating data")
cat("\n--------------------------------------------------------------------------\n")
print(Stat.Obj)

#===============================================================================
# 3. Estimation of both ranking and rating data using different 
#    means
#===============================================================================
cfg <- list(k.rg = 4, rating = T, restriction = "extended")

Opti.Obj <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "MIX.Rank", test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results
cat("\n-------------------------------------------------------------------------\n")
cat(" MIX-Rank 3:\n")
cat(" Results of Kellen, Klauer & Singmann, 2012: ranking and rating data\n")
cat(" Extended restriction: The mean of non-target distribution is not zero") 
cat("\n-------------------------------------------------------------------------\n")
print(Stat.Obj)

#===============================================================================
# 4. Estimation of both ranking and rating data
#    Simulation of the unequal variance SDT model
#===============================================================================
cfg <- list(k.rg = 4, rating = T, restriction = "SDT")
Opti.Obj <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "MIX.Rank", test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj)			# Evaluate the results
cat("\n-------------------------------------------------------------------------\n")
cat(" MIX-Rank 4:\n")
cat(" Results of Kellen, Klauer & Singmann, 2012: ranking and rating data\n")
cat(" Simulation of standard unequal variance SDT model") 
cat("\n-------------------------------------------------------------------------\n")
print(Stat.Obj)