# ================================================================
# Examples of the documentation of SDT Models:
# SDT-1.2: Modeling of Yes/No data with multiple signals
# Source: Macmillan & Creelman (2005)
#
# Date of last update: March 2018
# Autor: Siegfried Macho
# ================================================================

library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/"
DirSourceM <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))


datavec <- c(98, 	2,     # Signal 1
	           94, 	6,     # Signal 2
             85, 15,     # Signal 3
             60, 40,     # Signal 4)	
             20, 80,     # Signal 5	
              8, 92,     # Signal 6	
              4, 96)     # Signal 7	

# List with configuration information: All 7 distribution are normal with variance 1
cfg   <- list(n.sdt = 7, restriction = "equalvar")

# Print Parameters
PI <- SDT.Parameter.Info(data = datavec, n = cfg)
cat("\n------------------------------------------\n")
cat("  Parameter-Information (SDT-Model):")
cat("\n------------------------------------------\n")
print(PI)

# ESTIMATE AND EVALUATE THE RESULTS
Opti.Obj <- SDT.Estimate(data = datavec, n = cfg, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj, control = list(LR = T))
print(Stat.Obj)

# PLOT CONFIGURATION
SDT.Plot(Opti.Obj, cols = 1:7, labels = c("Memory Strength", "Density"), SDT.legend = list(text = paste("Signal", 1:7)))
