# =============================================================
# SDT-2D-8-2:     Example of the SDT-2D MODEL
#                 Estimation of polychiric coerrelation
#                 Data from Ollson (1979), Table 7 on p.456
#
# Author: Siegfried Macho
# Date of last update: September, 2013
# =============================================================
library(ellipse)

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"			
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-SDT-2D.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT-2D MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# LOAD DATA: Ollson, 1979, Table 7, on p.456
data <- c(13, 69, 41, 6, 113, 132, 0, 22, 104)

# CONFIGURATION OF THE MODEL
cfg <- list(n.sdt = 1, k1 = 2, k2 = 2)

# CALL ESTIMATION MODULE AND PRINT THE RESULT
Opti.obj <- SDT.Estimate(data = data, n = cfg, Model.Id = "SDT.2D", test = T)

# COMPUTE AND PRINT STATISTICS
Stat.Obj <- SDT.Statistics(Opti.obj)
cat("\n==================================================\n")
cat(" Results for the data of Olzak and Kramer (1984):")
cat("\n==================================================\n")
print(Stat.Obj)

# PLOT CONFIGURATION
xy.labels <- c("Satisfaction", "Quality")
SDT.Plot(Opti.obj, cols = 3:6, labels = xy.labels)
