# ================================================================
# SDT-IRF-Gauss 1: Fitting models to data
# Data:  Ratcliff et al. 1994, Exp.1 Pure strong items
#
# Date of last update: May, 2019
# Author: Siegfried Macho
# ================================================================
# LIBRARY REQUIRED SINCE THE TESTFLAG IN ESTIMATION PROCEDURE IS SET TO TRUE
library(numDeriv)

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/"
DirSourceM <- "C:/Users/macho/Documents/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-IRF-Gauss.R"

# FILE NAMES FOR ESTIMATION 
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH MODEL AS WELL AS AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSourceM, Model, sep = ""))
source(paste(DirSource,  Auxiliary, sep = ""))
source(paste(DirSource,  Main, sep = ""))


# DATA OF RATCLIFF ET AL. (1994, Exp.1, 200 ms pure strong list)
datavec <- c(477, 776, 527, 321, 258, 184,			# New
	           192, 401, 290, 267, 316, 442)			# Old


# FIT SDT-GRM MODEL AND COMPUTE OUTPUT
cfg <- list(n.sdt = 2, model = "GRM")
Opti.GRM <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "IRF.Gauss", test = T)
Stat.GRM <- SDT.Statistics(Opti.GRM)

# FIT SDT-ORM MODEL AND COMPUTE OUTPUT
cfg <- list(n.sdt = 2, model = "ORM")
Opti.ORM <- SDT.Estimate(data = datavec, n = cfg, Model.Id = "IRF.Gauss", test = T)
Stat.ORM <- SDT.Statistics(Opti.ORM)

# PRINT THE RESULTS
cat("\n-----------------------------------------------------------------------\n")
cat(" Results of the GRM-SDT (Graded Response) model:\n")
cat(" Data: Ratcliff, MacKoon, & Tindall, 1994, Exp.1, pure strong items")
cat("\n-----------------------------------------------------------------------\n")
print(Stat.GRM)
cat("\n-----------------------------------------------------------------------\n")
cat(" Results of the ORM-SDT (Ordinal Rasch) model:\n")
cat(" Data: Ratcliff, MacKoon, & Tindall, 1994, Exp.1, pure strong items")
cat("\n-----------------------------------------------------------------------\n")
print(Stat.ORM)
