# ================================================================
# Examples of the documentation of mAFC Models:
# SDT-mAFC-1: m-alternative forced choice SDT
#
# Date of creation: October, 2012
# Autor: Siegfried Macho
# ================================================================
library(numDeriv)

#----------------------------------------------------------------
#  GH-Structure:  GH.Structure[,1] = points
#                 GH.Structure[,2] = weights for GH
#                 GH.Structure[,3] = weights for adaptive GH
#----------------------------------------------------------------

# DIRECTORIES (PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSourceM  <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"
DirSource   <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"

# FILE NAME WITH THE MODEL 
Model <- "SDT-mAFC.R"

# FILE NAMES FOR ESTIMATION 
Main       <- "SDT-Main.R"
Auxiliary  <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODEL
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# Data of Ennis & Mahony (1995), p. 1089, Condition WW
datavec1 <- c(54,  5,  1,        # SWW
	         0, 60,  0,        # WSW
	         5,  3, 52)        # WWS

# Data of Ennis & Mahony (1995), p. 1089, Condition SS
datavec2 <- c(40, 12,  8,        # SWW
	         6, 49,  4,        # WSW
	         6,  5, 49)        # WWS

# CONFIGURATION
cfg <- list(s = 1, m = 3, quad = "aGH")

# SET FIXED CONSTRAINT: FIX VARIANCE OF TARGET TO 1.0
fixed <- matrix(c(1, 2), nr = 2, byrow = T)

# ESTIMATE AND EVALUATE THE RESULTS
Opti.Obj <- SDT.Estimate(data = datavec1, n = cfg, Model.Id = "mAFC", fixed = fixed, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj, deci = 3)

cat("\n---------------------------------------------------\n")
cat(" 1. Ennis & Mahony (1995), Condition WW\n")
cat("    using adaptive Gauss-Hermite Quadrature")
cat("\n---------------------------------------------------\n")
print(Stat.Obj)

# ESTIMATE AND EVALUATE THE RESULTS
cat("\n---------------------------------------------------\n")
cat(" 2. Ennis & Mahony (1995), Condition SS\n")
cat("    using adaptive Gauss-Hermite Quadrature")
cat("\n---------------------------------------------------\n")
Opti.Obj <- SDT.Estimate(data = datavec2, n = cfg, Model.Id = "mAFC", fixed = fixed, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj, deci = 3)
print(Stat.Obj)

# ESTIMATE AND EVALUATE THE RESULTS  OF BOTH DATASETS TOGETHER WITH GAUSSIAN QUARDATURE
cfg <- list(s = 2, m = 3, quad = "GH")
fixed <- matrix(c(1, 1, 2, 6),  nr = 2, byrow = T)    # Fix sd = 1 in both conditions

cat("\n---------------------------------------------------\n")
cat(" 3. Ennis & Mahony (1995), Condition WW + SS\n")
cat("    using Gauss-Hermite Quadrature")
cat("\n---------------------------------------------------\n")
Opti.Obj <- SDT.Estimate(data = c(datavec1, datavec2), n = cfg, Model.Id = "mAFC", fixed = fixed, test = T)
Stat.Obj <- SDT.Statistics(Opti.Obj, deci = 3)
print(Stat.Obj)
