# ====================================================================
# Ex.2: SDT2D-MIX-2 model
# Data: Slotnick, Klein, Dodson, & Shimamura (2000), Exp. 2
#
# Date of creation: July, 2013
# Autor: Siegfried Macho
# ====================================================================

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"
DirData    <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/Data/"

# FILE NAME WITH THE MODEL
Model.Base <- "SDT-SDT-2D.R"
Model <- "SDT2D-MIX-2.R"

# FILE NAMES FOR ESTIMATION
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"
Data      <- "Slotnick et al. (2000, Exp.2).dat"

# LOAD SOURCE FILES WITH SDT MODELS
source(paste(DirSourceM, Model.Base, sep = ""))
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# LOAD DATA: SLOTNICK ET AL. (2000): Order: NEW, MALE, FEMALE
Dat <- read.table(paste(DirData, Data, sep = ""), header = T)
data.vec <- c(Dat[, 1], Dat[, 2], Dat[, 3])

# CONFIGURATION INFORMATION
cfg <- list(s = 3, k1 = 6, k2 = 6, standard = F, ds = 1, robust = T)	 # Configuration: ds = 0

##################################
# CONSTRAINTS
# D1: Source, D2: Old/New
# Model 1: p, m1, m2, s1, s2, r:
#          1,  0,  0,  1,  1,  0,
#              0,  0,  1,  1,  0,
#
# Model 2: d,  0,  a,  1,  1,  0,
#              c,  b,  1,  1,  0,

#
# Model 3: d,  0,  a,  1,  1,  0,
#             -c,  b,  1,  1,  0,
##################################
  
fixed.M1 <- matrix(c(1, 0, 0, 1, 1, 0, 0, 0, 1, 1, 0,
                     1:11), nr = 2, byrow = T)
                     
fixed.M2 <- matrix(c( 0,  1,  1,  0,  1,  1,  0,
                     13, 15, 16, 17, 20, 21, 22), nr = 2, byrow = T)
                     
fixed.M3 <- matrix(c( 0,  1,  1,  0,  1,  1,  0,
                     24, 26, 27, 28, 31, 32, 33), nr = 2, byrow = T)
                     
                     
fixed <- cbind(fixed.M1, fixed.M2, fixed.M3)
                     
# Targets of functional constraints
fixed.fct <- matrix(c(12,  0,
                      23, 29), nr = 2, byrow = T)
                      
fixed <- cbind(fixed, fixed.fct)                    

# Equaltity cosntraints
ident <- matrix(c(14, 19, 
                  25, 30), nr = 2, byrow = T)

fct.m <- function(par)
{
	tindex <- 29     			# Target index: Mean.x[3.2]
	sindex <- 18			# Source index: Mean.x[2.2]

	par[tindex] <- -par[sindex]

	# Define Gradient function
	gr.fct <- function(grad, par)
	{
		grad[sindex] <- grad[sindex] - grad[tindex]
		return(grad)
	}
	attr(par, "SDT.gradient") <- gr.fct			# Gradient
	
	return(par)
}
# 4 DEFINE FUNCTION TO COMPUTE Jacobian AND ASSIGN IT TO THE FUNCTION
J.fct <- function(par)
{
      J <- diag(length(par))
      J[29, 18] <- -1
      J
}   
attr(fct.m, "SDT.Jacobian") <- J.fct			# Jacobian matrix



#-------------------------------------------------------------------------------
# SHOW THE CONFIGURATION
#-------------------------------------------------------------------------------
Par.Info <- SDT.Parameter.Info(n = cfg, Model.Id = "SDT2D.MIX.2", fixed = fixed, ident = ident, deci = 3)
print(Par.Info)

#-------------------------------------------------------------------------------
# ESTIMATION OF PARAMETERS AND EVALUATION OF RESULTS
#-------------------------------------------------------------------------------
Est.Obj <- SDT.Estimate(data = data.vec, Model.Id = "SDT2D.MIX.2", n = cfg, fixed = fixed, ident = ident, functional = fct.m, test = T)
Stat.Obj <- SDT.Statistics(Est.Obj)

cat("\n-------------------------------------------------------------------------\n")
cat(" Slotnick, Klein, Dodson, & Shimamura (2000), Experiment 2:")
cat("\n-------------------------------------------------------------------------\n")
print(Stat.Obj)

-------------------------------------------------------------------------------
# PLOT THE CONFIGURATION: 
# Gaussian of New in blue, the other Gaussians are red
#-------------------------------------------------------------------------------
SDT.Plot(Est.Obj, cols = c(1, 2, 2, 2, 2), ltys = NULL, labels = c("Source", "Old/New"), SDT.legend = NULL, option = NULL)