# ====================================================================
# SDT2D-MIX-2 model, Example 1
# Data: Yonelinas (1999), Experiment 2
#
# Date of creation: July, 2013
# Autor: Siegfried Macho
# ====================================================================

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"

# FILE NAME WITH THE MODELS: SDT2D-MIX-2 REQUIRES SDT-SDT-2D
Model.Base <- "SDT-SDT-2D.R"
Model      <- "SDT2D-MIX-2.R"

# FILE NAMES FOR ESTIMATION
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"

# LOAD SOURCE FILES WITH SDT MODELS
source(paste(DirSourceM, Model.Base, sep = ""))
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# LOAD DATA: YONELINAS (1999): Order: NEW, MALE, FEMALE
New    <- c( 9,  14,   3,  15,  15,  22, 
            46,  37,  49,  38,  54,  20, 
           246, 296, 166, 124,  37,  14, 
           150, 181, 118,  57,  35,   9,
            13,  15,   8,  20,  48,  24,
             7,   4,   1,   2,  11,  12)
         
Male   <- c( 6,   4,   4,   2,  12,  79,
            16,  29,  34,  35,  77,  64,
            71, 130, 119,  84,  43,  75,
            43,  75,  82,  68,  48,  40,
             3,   2,   7,  27,  71, 119,
             3,   2,   0,   3,  10, 433)
             
Female <- c( 3,   8,   5,   8,  24, 489,
            16,  26,  20,  33, 105, 119,
            83, 113, 101,  82,  51,  62,
            30,  78,  86,  54,  40,  40,
             5,   4,   8,  26,  45,  56,
             2,   1,   3,   1,   9,  84)         

data.vec <- c(New, Male, Female)

# CONFIGURATION INFORMATION
cfg <- list(s = 3, k1 = 5, k2 = 5, standard = F, ds = 1, robust = T)

##################################
# CONSTRAINTS
# D1: Source recognition
# D2: Old/New recognition
#
# Model 1: p, m1, m2, s1, s2, r:
#          1,  0,  0,  1,  1,  0,
#              0,  0,  1,  1,  0,
#
# Model 2: *,  0,  a,  1,  1,  0,
#              c,  b,  1,  1,  0,
#
# Model 3: *,  0,  a,  1,  1,  0,
#             -c,  b,  1,  1,  0,
##################################
  
# Fixed restrictions for Model 1  
fixed.M1 <- matrix(c(1, 0, 0, 1, 1, 0, 0, 0, 1, 1, 0,
                     1:11), nr = 2, byrow = T)
# Fixed restrictions for Model 2
fixed.M2 <- matrix(c( 0,  1,  1,  0,  1,  1,  0,
                     13, 15, 16, 17, 20, 21, 22), nr = 2, byrow = T)
                     
# Fixed restrictions for Model 3
fixed.M3 <- matrix(c( 0,  1,  1,  0,  1,  1,  0,
                     24, 26, 27, 28, 31, 32, 33), nr = 2, byrow = T)
                     
# Target of functional constraints
fixed.fct <- matrix(c( 0,
                      29), nr = 2, byrow = T)
                      
fixed <- cbind(fixed.M1, fixed.M2, fixed.M3, fixed.fct)                    

ident <- matrix(c(14, 19, 
                  25, 30), nr = 2, byrow = T)

# Functional constraint: 
# Mean.x of Model 2, second Gaussian = Mean.x of Model 3, second Gaussian
fct.m <- function(par)
{
	tindex <- 29     			# Target index: Mean.x[3.2]
	sindex <- 18			# Source index: Mean.x[2.2]

	par[tindex] <- -par[sindex]

	# Define Gradient function
	gr.fct <- function(grad, par)
	{
		grad[sindex] <- grad[sindex] - grad[tindex]
		return(grad)
	}
	attr(par, "SDT.gradient") <- gr.fct			# Gradient
	
	return(par)
}
# 4 DEFINE FUNCTION TO COMPUTE Jacobian AND ASSIGN IT TO THE FUNCTION
J.fct <- function(par)
{
      J <- diag(length(par))
      J[29, 18] <- -1
      J
}   
attr(fct.m, "SDT.Jacobian") <- J.fct			# Jacobian matrix

#-------------------------------------------------------------------------------
# SHOW THE CONFIGURATION
#-------------------------------------------------------------------------------
Par.Info <- SDT.Parameter.Info(n = cfg, Model.Id = "SDT2D.MIX.2", fixed = fixed, ident = ident, deci = 3)
print(Par.Info)

#-------------------------------------------------------------------------------
# ESTIMATION OF PARAMETERS AND EVALUATION OF RESULTS
#-------------------------------------------------------------------------------
Est.Obj <- SDT.Estimate(data = data.vec, Model.Id = "SDT2D.MIX.2", n = cfg, fixed = fixed, ident = ident, functional = fct.m, test = T)
Stat.Obj <- SDT.Statistics(Est.Obj)

cat("\n-------------------------------------------------------------------------\n")
cat(" Yonelinas (1999), Experiment 2:")
cat("\n-------------------------------------------------------------------------\n")
print(Stat.Obj)

#-------------------------------------------------------------------------------
# PLOT THE CONFIGURATION: 
# Gaussian of New in blue, the other Gaussians are red
#-------------------------------------------------------------------------------
SDT.Plot(Est.Obj, cols = c(1, 2, 2, 2, 2), labels = c("Source", "Old/New"))