# ====================================================================
# Ex.1: SDT2D-MIX-3 model
# Data: Yonelinas (1999), Exp. 2
#
# Date of creation: July, 2012
# Autor: Siegfried Macho
# ====================================================================

# DIRECTORIES (my computer, PLEASE ADJUST TO YOUR PERSONAL SETTING)
DirSource <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/"
DirSourceM <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/R-Code/Models/"
DirData    <- "C:/Documents and Settings/macho/Statistik/_SDT-Models (Version 2)/Data/"

# FILE NAME WITH THE MODEL
Model.Base <- "SDT-SDT-2D.R"
Model <- "SDT2D-MIX-3.R"

# FILE NAMES FOR ESTIMATION
Main      <- "SDT-Main.R"
Auxiliary <- "SDT-Auxiliary.R"
Data      <- "Yonelinas (1999, Exp.2).dat"

# LOAD SOURCE FILES WITH SDT MODELS
source(paste(DirSourceM, Model.Base, sep = ""))
source(paste(DirSourceM, Model, sep = ""))

# LOAD SOURCE FILES WITH AUXILIARY AND ESTIMATION FUNCTIONS
source(paste(DirSource, Auxiliary, sep = ""))
source(paste(DirSource, Main, sep = ""))

# LOAD DATA: YONELINAS (1999)
Dat <- read.table(paste(DirData, Data, sep = ""), header = T)
data.vec <- c(Dat[, 3], Dat[, 1], Dat[, 2])

# CONFIGURATION INFORMATION
cfg <- list(s = 3, k1 = 5, k2 = 5, standard = F, ds = 1, robust = T)	 # Configuration: ds = 0

##################################
# CONSTRAINTS
# D1: Source, D2: Old/New
# Model 1: p, m1, m2, s1, s2, r:
#          1,  0,  0,  1,  1,  0,
#          0,  0,  0,  1,  1,  0,
#          0,  0,  0,  1,  1,  0,
#
# Model 2: 0,  0,  0,  1,  1,  0,
#          *   0,  a,  1,  1,  0,
#          *   c,  b,  1,  1,  0,

#
# Model 3: 0,  0,  0,  1,  1,  0,
#          *   0,  a,  1,  1,  0,
#          *  -c,  b,  1,  1,  0,
##################################
  
fixed <- matrix(c(1, 0, 0, 1, 1, 0, rep(c(0, 0, 0, 1, 1, 0), 3),   0, 1, 1, 0,    1, 1, 0,  0, 0, 0, 1, 1, 0,  0, 1, 1, 0,  1, 1, 0,
                  1, 2, 3, 4, 5, 6, 7:24,                         26, 28:30  ,    34:36  ,  37:42           ,  44, 46:48 ,  52:54  ), nr = 2, byrow = T)

# Targets of functional constraints
fixed.fct <- matrix(c( 0,
                      50), nr = 2, byrow = T)
fixed <- cbind(fixed, fixed.fct)                    


ident <- matrix(c(27, 33,
                  45, 51), nr = 2, byrow = T) 

fct.m <- function(par)
{
	tindex <- 50     			# Target index: Mean.x[3.3]
	sindex <- 32			# Source index: Mean.x[2.3]

	par[tindex] <- -par[sindex]

	# Define Gradient function
	gr.fct <- function(grad, par)
	{
		grad[sindex] <- grad[sindex] - grad[tindex]
		return(grad)
	}
	attr(par, "SDT.gradient") <- gr.fct			# Gradient
	
	return(par)
}
# 4 DEFINE FUNCTION TO COMPUTE Jacobian AND ASSIGN IT TO THE FUNCTION
J.fct <- function(par)
{
      J <- diag(length(par))
      J[50, 32] <- -1
      J
}   
attr(fct.m, "SDT.Jacobian") <- J.fct			# Jacobian matrix





#-------------------------------------------------------------------------------
# SHOW THE CONFIGURATION
#-------------------------------------------------------------------------------
Par.Info <- SDT.Parameter.Info(n = cfg, Model.Id = "SDT2D.MIX.3", fixed = fixed, ident = ident, deci = 3)
print(Par.Info)

#-------------------------------------------------------------------------------
# ESTIMATION OF PARAMETERS AND EVALUATION OF RESULTS
#-------------------------------------------------------------------------------
Est.Obj <- SDT.Estimate(data = data.vec, Model.Id = "SDT2D.MIX.3", n = cfg, fixed = fixed, ident = ident, functional = fct.m, test = T)
Stat.Obj <- SDT.Statistics(Est.Obj)

cat("\n-------------------------------------------------------------------------\n")
cat(" Yonelinas (1999), Experiment 2:")
cat("\n-------------------------------------------------------------------------\n")
print(Stat.Obj)
